@@ -1,9 +1,42 @@
 #!/bin/sh
 
-# DIR_SCRIPT="$( cd "$( dirname "${BASH_SOURCE[0]}" )" && pwd )"  # absolute path to the dir of this script
-# source $DIR_SCRIPT/config.sh   # check for important paramters
+source $QMSDEVDIR/qmapshack/MacOSX/config.sh   # check for important paramters
+
+# Directories for QMS
+SRC_RESOURCES_DIR=$SRC_OSX_DIR/resources
+BUILD_BIN_DIR=$QMSDEVDIR/build_QMapShack/bin
+
+# vars for bundling
+set -a
+declare APP_LANG=("ca" "cs" "de" "en" "es" "fr" "nl" "ru")
+APP_NAME_LOWER="$(tr [A-Z] [a-z] <<< "$APP_NAME")"
+APP_BUNDLE=$APP_NAME.app
+
+APP_BUNDLE_QMAPTOOL=QMapTool.app
+
+BUILD_BUNDLE_DIR=$BUILD_RELEASE_DIR/$APP_BUNDLE
+BUILD_BUNDLE_CONTENTS_DIR=$BUILD_BUNDLE_DIR/Contents
+BUILD_BUNDLE_APP_DIR=$BUILD_BUNDLE_DIR/Contents/MacOS
+BUILD_BUNDLE_RES_DIR=$BUILD_BUNDLE_DIR/Contents/Resources
+BUILD_BUNDLE_FRW_DIR=$BUILD_BUNDLE_DIR/Contents/Frameworks
+BUILD_BUNDLE_PLUGIN_DIR=$BUILD_BUNDLE_DIR/Contents/PlugIns
+BUILD_BUNDLE_EXTLIB_DIR=$BUILD_BUNDLE_DIR/Contents/lib
+BUILD_BUNDLE_APP_FILE=$BUILD_BUNDLE_APP_DIR/$APP_NAME
+
+BUILD_BUNDLE_RES_QM_DIR=$BUILD_BUNDLE_RES_DIR/translations
+BUILD_BUNDLE_RES_GDAL_DIR=$BUILD_BUNDLE_RES_DIR/gdal
+BUILD_BUNDLE_RES_GDAL_PLUGINS_DIR=$BUILD_BUNDLE_RES_DIR/gdalplugins
+BUILD_BUNDLE_RES_GEOS_DIR=$BUILD_BUNDLE_RES_DIR/geos
+BUILD_BUNDLE_RES_PROJ_DIR=$BUILD_BUNDLE_RES_DIR/proj
+BUILD_BUNDLE_RES_ROUTINO_DIR=$BUILD_BUNDLE_RES_DIR/routino
+BUILD_BUNDLE_RES_HELP_DIR=$BUILD_BUNDLE_RES_DIR/help
+BUILD_BUNDLE_RES_BIN_DIR=$BUILD_BUNDLE_CONTENTS_DIR/Tools
+
+HELP_QMS_DIR=$QMS_SRC_DIR/src/qmapshack/doc
+HELP_QMT_DIR=$QMS_SRC_DIR/src/qmaptool/doc
+
+set +a
 
-SRC_RESOURCES_DIR=$QMS_SRC_DIR/MacOSX/resources
 
 APP_VERSION=0
 BUILD_TIME=$(date +"%y-%m-%dT%H:%M:%S")
@@ -39,8 +72,9 @@ function buildAppStructure {
     #         *.icns
     #      Frameworks/
     #         <libs>
-    #      PlugIns
+    #      PlugIns/
     #         <libs>
+    #      Tools/
     #      libs/
 
     rm -rf $BUILD_BUNDLE_DIR
@@ -51,7 +85,7 @@ function buildAppStructure {
     mkdir $BUILD_BUNDLE_RES_QM_DIR
     mkdir $BUILD_BUNDLE_FRW_DIR
     mkdir $BUILD_BUNDLE_PLUGIN_DIR
-    if [[ "$BREW_PACKAGE_BUILD" == "" ]] ; then
+    if [ "$BREW_PACKAGE_BUILD" = "" ] ; then
         mkdir $BUILD_BUNDLE_EXTLIB_DIR
     fi
 
@@ -68,8 +102,8 @@ function buildAppStructure {
 
     cp -v $SRC_RESOURCES_DIR/$APP_NAME.icns $BUILD_BUNDLE_RES_DIR
     cp -v $SRC_RESOURCES_DIR/*.qss $BUILD_BUNDLE_RES_DIR
-    # inject PATH of HOMEBREW, so that external tools can be run from the app bundles
-    sed  "s|HOMEBREW|$HOMEBREW_PREFIX|" $SRC_RESOURCES_DIR/Info.plist > $QMSDEVDIR/Info.plist
+    # inject PATH of PACKAGES_PATH, so that external tools can be run from the app bundles
+    sed  "s|PACKAGES_PATH|$PACKAGES_PATH|" $SRC_RESOURCES_DIR/Info.plist > $QMSDEVDIR/Info.plist
     mv $QMSDEVDIR/Info.plist $BUILD_BUNDLE_CONTENTS_DIR
 
     # new icon, if one has been created (otherwise the one from predefined data)
@@ -82,26 +116,37 @@ function buildAppStructure {
     cp -v $BUILD_BIN_DIR/$APP_NAME_LOWER  $BUILD_BUNDLE_APP_DIR/$APP_NAME
 
     # app translations
-    cp -v $BUILD_DIR/src/$APP_NAME_LOWER/*.qm $BUILD_BUNDLE_RES_QM_DIR
+    cp -v $BUILD_QMAPSHACK_DIR/src/$APP_NAME_LOWER/*.qm $BUILD_BUNDLE_RES_QM_DIR
 }
 
 
-function copyQtTrqnslations {
+function copyQtTranslations {
+    QT_TRANSLATIONS_DIR=$(find -L $QT_DEV_PATH -type d -name translations | head -n1)
     for i in "${APP_LANG[@]}"
     do
-        cp -v $QT_DIR/translations/*_${i}.qm $BUILD_BUNDLE_RES_QM_DIR
+        #for MOD in qtbase qtmultimedia qtquickcontrols2 qtdeclarative
+        for MOD in qtbase
+        do
+            FILE="$QT_TRANSLATIONS_DIR/${MOD}_${i}.qm"
+            if [ -f "$FILE" ]; then
+                echo "Copying $FILE to $BUILD_BUNDLE_RES_QM_DIR/"
+                cp -v "$FILE" "$BUILD_BUNDLE_RES_QM_DIR/"
+            fi
+        done
     done
 }
 
 
 function qtDeploy {
     # -no-strip
-    echo "MACdeployQT  $QT_DIR/ und  $BUILD_BUNDLE_DIR/"
-    $QT_DIR/bin/macdeployqt $BUILD_BUNDLE_DIR -always-overwrite -verbose=3
+    echo "MACdeployQT  $QT_DEV_PATH/ and  $BUILD_BUNDLE_DIR/"
+    $QT_DEV_PATH/bin/macdeployqt $BUILD_BUNDLE_DIR -always-overwrite -verbose=3
 }
 
 
 function printLinkingApp {
+    echo "--------------------------------------------"
+    echo "*** printLinkingApp ***"
     printLinking $BUILD_BUNDLE_APP_FILE
 
     for F in `find $BUILD_BUNDLE_FRW_DIR -type f -type f \( -iname "*.dylib" -o -iname "*.so" \)`
@@ -109,12 +154,11 @@ function printLinkingApp {
         printLinking $F
     done
 
-    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/5 -type f -maxdepth 1`
+    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/A -type f -maxdepth 1`
     do
         printLinking $F
     done
-
-    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/5/Helpers/QtWebEngineProcess.app/Contents/MacOS/QtWebEngineProcess -type f -maxdepth 1`
+    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/A/Helpers/QtWebEngineProcess.app/Contents/MacOS/QtWebEngineProcess -type f -maxdepth 1`
     do
         printLinking $F
     done
@@ -131,12 +175,11 @@ function printLinkingApp {
         checkLibraries $F
     done
 
-    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/5 -type f -maxdepth 1`
+    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/A -type f -maxdepth 1`
     do
         checkLibraries $F
     done
-
-    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/5/Helpers/QtWebEngineProcess.app/Contents/MacOS/QtWebEngineProcess -type f -maxdepth 1`
+    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/A/Helpers/QtWebEngineProcess.app/Contents/MacOS/QtWebEngineProcess -type f -maxdepth 1`
     do
         echo $F
         checkLibraries $F
@@ -154,19 +197,23 @@ function adjustLinking {
     for F in `find $BUILD_BUNDLE_PLUGIN_DIR -type f -type f \( -iname "*.dylib" -o -iname "*.so" \)`
     do
         adjustLinkQt $F "libq"
-        adjustLinkQt $F "$HOMEBREW_PREFIX/"
+        # adjustLinkQt $F "$PACKAGES_PATH/"
     done
 
-    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/5 -type f -maxdepth 1`
+    for F in `find $BUILD_BUNDLE_FRW_DIR/Qt*.framework/Versions/A -type f -maxdepth 1`
     do
-        adjustLinkQt $F "$HOMEBREW_PREFIX/"
+        adjustLinkQt $F "$PACKAGES_PATH/"
     done
 
     for F in `find $BUILD_BUNDLE_FRW_DIR -type f -type f \( -iname "*.dylib" -o -iname "*.so" \)`
     do
         adjustLinkQt $F "Qt"
-        adjustLinkQt $F "libroutino"
-        adjustLinkQt $F "$HOMEBREW_PREFIX/"
+        if [ -z "$MACPORTS_BUILD" ]; then
+            adjustLinkQt $F "libroutino"
+        fi
+        # echo "--- Adjusting libs with references to $PACKAGES_PATH ---"
+        adjustLinkDyLib $F
+        
     done
 
     adjustLinkQt $BUILD_BUNDLE_APP_FILE "Qt"
@@ -176,7 +223,7 @@ function adjustLinking {
     # QtWebEngineProcess.app is an app within QtWebEngineCore.framework, which references other Qt frameworks
     PATH_TO_QTWEBENGINEPROCESS="QtWebEngineCore.framework/Helpers/QtWebEngineProcess.app"
     F=$BUILD_BUNDLE_FRW_DIR/$PATH_TO_QTWEBENGINEPROCESS/Contents/MacOS/QtWebEngineProcess
-    adjustLinkQt $F "$HOMEBREW_PREFIX/"
+    adjustLinkQt $F "$PACKAGES_PATH/"
     if [ -d "$BUILD_BUNDLE_FRW_DIR/$PATH_TO_QTWEBENGINEPROCESS/Contents" ]; then
         pushd $BUILD_BUNDLE_FRW_DIR/$PATH_TO_QTWEBENGINEPROCESS/Contents
         ln -s ../../../../../../../Frameworks .
@@ -184,6 +231,61 @@ function adjustLinking {
     fi
 }
 
+function adjustLinkDyLib {
+    echo "adjustLinkDyLib >>> Adjusting dylibs of `basename $1`"
+    F=$1 # file
+    
+    # exclude symlinks
+    if [ -L "$F" ]; then
+        return
+    fi
+
+    for P in `otool -L $F | awk '{print $1}'`
+    do
+        LIB=`basename $P`
+        # 1. adjust libraries from the package path
+        case "$P" in
+           "$PACKAGES_PATH"*) 
+             PREL="@executable_path/../Frameworks/$LIB"
+             echo "Changing $LIB to reference $PREL"
+             sudo install_name_tool -change $P $PREL $F
+             ;;
+
+           # 2. adjust rpath libraries that are known to cause problems
+           @rpath/libproj.25.dylib)
+             echo "Fixing libproj @rpath in $F"
+             sudo install_name_tool -change @rpath/libproj.25.dylib \
+                 @executable_path/../Frameworks/libproj.25.dylib $F
+             ;;
+        esac
+    done
+}
+
+function adjustLinkExtTool {
+    # $1 = filename of exttool
+    echo ">>> Adjusting ext Tools of $1"
+    for P in `otoolrecursive $1`
+    do
+
+        LIB=${P##*/}    
+        LIB=${LIB%%:}
+        PREL="@executable_path/../Frameworks/$LIB"
+
+        case "$P" in
+            *".framework"*)
+                LIB_VERSION=Versions/A
+                LIB=$LIB.framework/$LIB_VERSION/$LIB
+                PREL="@executable_path/../Frameworks/$LIB"
+                ;;
+            *)
+                echo "cp -v $P ../Frameworks/"
+                ;;
+        esac
+   
+        echo "install_name_tool -change $P $PREL `basename $1`"
+        install_name_tool -change $P $PREL $1
+    done
+}
 
 function adjustLinkQt {
     F=$1 # file
@@ -192,25 +294,34 @@ function adjustLinkQt {
 
     for P in `otool -L $F | awk '{print $1}'`
     do
-        #  replace double slashes
-        if [[ "$P" == *//* ]]; then 
-            PSLASH=$(echo $P | sed 's,//,/,g')
-            sudo install_name_tool -change $P $PSLASH $F
+        # exclude symlinks
+        if [ -L "$P" ]; then
+            break
         fi
+        #  replace double slashes
+        case "$P" in
+            *//*)
+                PSLASH=$(echo $P | sed 's,//,/,g')
+                sudo install_name_tool -change $P $PSLASH $F
+                ;;
+        esac
 
-        LIB=${P##*/}
+        LIB=${P##*/}    
         LIB=${LIB%%:}
         PREL="@executable_path/../Frameworks/$LIB"
 
-        if [[ "$P" == *".framework"* ]]; then
-            LIB_VERSION=Versions/5
-            LIB=$LIB.framework/$LIB_VERSION/$LIB
-            PREL="@executable_path/../Frameworks/$LIB"
-        elif [[ "$P" == *"PlugIns"* ]]; then
-            # subdirectory for PlugIns
-            LIB=${P##*PlugIns/} # remove prepart
-            PREL="@executable_path/../PlugIns/$LIB"
-        fi
+        case "$P" in
+            *".framework"*)
+                LIB_VERSION=Versions/A
+                LIB=$LIB.framework/$LIB_VERSION/$LIB
+                PREL="@executable_path/../Frameworks/$LIB"
+                ;;
+            *"PlugIns"*)
+                # subdirectory for PlugIns
+                LIB=${P##*PlugIns/} # remove prepart
+                PREL="@executable_path/../PlugIns/$LIB"
+                ;;
+        esac
 
         echo "-----"
         echo "F    = $F"
@@ -220,12 +331,18 @@ function adjustLinkQt {
         echo "LIB  = $LIB"
         echo "PREL = $PREL"
 
-        if [[ "$P" == "$FREL" ]]; then
+        if [ "$P" = "$FREL" ]; then
             echo "no update - is a relativ id"
-		elif [[ "$LIB" == *"$FREL" ]]; then
+        elif echo "$LIB" | grep -q "$FREL"; then
             echo "name_tool: $FREL >> $PREL ($P)"
             sudo install_name_tool -id $PREL $F
-        elif [[ "$P" == *$L* ]]; then
+        elif echo "$P" | grep -q "$L"; then
+            echo "name_tool: $FREL > $PREL ($P)"
+            sudo install_name_tool -change $P $PREL $F
+        elif echo "$P" | grep -q "^@loader_path"; then
+            echo "name_tool: $FREL > $PREL ($P)"
+            sudo install_name_tool -change $P $PREL $F
+        elif echo "$P" | grep -q "^@rpath"; then
             echo "name_tool: $FREL > $PREL ($P)"
             sudo install_name_tool -change $P $PREL $F
         fi
@@ -240,12 +357,15 @@ function adjustLinkingExtTools {
     do
         echo "F    = $F"
         install_name_tool -add_rpath @executable_path/../Frameworks $F
+        adjustLinkExtTool $F
     done
     echo "--------------------------------------------"
 }
 
 
 function printLinkingExtTools {
+    echo "--------------------------------------------"
+    echo "*** printLinkingExtTools ***"
     for F in `find $BUILD_BUNDLE_RES_BIN_DIR -type f ! \( -name "*.py" \)`
     do
         printLinking $F
@@ -299,7 +419,7 @@ function extractVersion {
     MINOR_VERSION=$(sed -E -n 's/.*_VERSION_MINOR.*([[:digit:]]+).*/\1/p' $QMS_SRC_DIR/src/$APP_NAME_LOWER/CMakeLists.txt)
     PATCH_VERSION=$(sed -E -n 's/.*_VERSION_PATCH.*([[:digit:]]+).*/\1/p' $QMS_SRC_DIR/src/$APP_NAME_LOWER/CMakeLists.txt)
 
-    if [[ -z "$MAJOR_VERSION" ]]; then
+    if [ -z "$MAJOR_VERSION" ]; then
          # project(QMapShack VERSION 1.11.0)
         MAJOR_VERSION=$(sed -E -n 's/.*QMapShack VERSION.*([[:digit:]]+)\.([[:digit:]]+)\.([[:digit:]]+).*/\1/p' $QMS_SRC_DIR/CMakeLists.txt)
         MINOR_VERSION=$(sed -E -n 's/.*QMapShack VERSION.*([[:digit:]]+)\.([[:digit:]]+)\.([[:digit:]]+).*/\2/p' $QMS_SRC_DIR/CMakeLists.txt)
@@ -334,14 +454,12 @@ function updateInfoPlist {
 }
 
 
-if [[ "$1" == "icon" ]]; then
+if [ "$1" = "icon" ]; then
     buildIcon
 fi
-if [[ "$1" == "info" ]]; then
+if [ "$1" = "info" ]; then
     printLinkingApp
 fi
-if [[ "$1" == "info-before" ]]; then
+if [ "$1" = "info-before" ]; then
     printLinking $BUILD_RELEASE_DIR/$APP_NAME
-    # TODO
-    # printLinking $LOCAL_ENV/lib/libroutino.so
 fi
