@@ -23,11 +23,11 @@
 #include "gis/CGisListWks.h"
 #include "gis/gpx/CGpxProject.h"
 #include "gis/tnv/CTwoNavProject.h"
+#include "misc.h"
 
 CDeviceTwoNav::CDeviceTwoNav(const QString& path, const QString& key, const QString& model, QTreeWidget* parent)
-    : IDevice(path, eTypeTwoNav, key, parent) {
-  setText(CGisListWks::eColumnName, QString("TwoNav (%1)").arg(model));
-  setToolTip(CGisListWks::eColumnName, QString("TwoNav (%1)").arg(model));
+    : IDevice(path, eTypeCompe, key, parent), model(model) {
+  name = QString("TwoNav (%1)").arg(model);
 
   if (QFile::exists(dir.absoluteFilePath("RegInfo.ini"))) {
     readReginfo(dir.absoluteFilePath("RegInfo.ini"));
@@ -45,24 +45,36 @@ CDeviceTwoNav::CDeviceTwoNav(const QString& path, const QString& key, const QStr
 
   {
     IGisProject* project = new CTwoNavProject(dirData.absolutePath(), this);
-    if (!project->isValid()) {
-      delete project;
+    if (project) {
+      if (!project->isValid()) {
+        delete project;
+      } else {
+        project->setVisibility(isVisible());
+      }
     }
   }
 
   const QStringList& entriesGpx = dirData.entryList(QStringList("*.gpx"));
   for (const QString& entry : entriesGpx) {
     IGisProject* project = new CGpxProject(dirData.absoluteFilePath(entry), this);
-    if (!project->isValid()) {
-      delete project;
+    if (project) {
+      if (!project->isValid()) {
+        delete project;
+      } else {
+        project->setVisibility(isVisible());
+      }
     }
   }
 
   const QStringList& entriesDir = dirData.entryList(QDir::NoDotAndDotDot | QDir::Dirs);
   for (const QString& entry : entriesDir) {
     IGisProject* project = new CTwoNavProject(dirData.absoluteFilePath(entry), this);
-    if (!project->isValid()) {
-      delete project;
+    if (project) {
+      if (!project->isValid()) {
+        delete project;
+      } else {
+        project->setVisibility(isVisible());
+      }
     }
   }
 
@@ -71,19 +83,25 @@ CDeviceTwoNav::CDeviceTwoNav(const QString& path, const QString& key, const QStr
   const QStringList& entriesLog = dirData.entryList(QStringList("*.gpx"));
   for (const QString& entry : entriesLog) {
     IGisProject* project = new CGpxProject(dirData.absoluteFilePath(entry), this);
-    if (!project->isValid()) {
-      delete project;
+    if (project) {
+      if (!project->isValid()) {
+        delete project;
+      } else {
+        project->setVisibility(isVisible());
+      }
     }
   }
 }
 
 CDeviceTwoNav::~CDeviceTwoNav() {}
 
+QString CDeviceTwoNav::getInfo(quint32) const { return QString("TwoNav (%1)").arg(model); }
+
 void CDeviceTwoNav::readReginfo(const QString& filename) {
   QString product, unittype;
   static const QRegularExpression re(QRegularExpression::anchoredPattern("(.*)=(.*)"));
   QFile file(filename);
-  file.open(QIODevice::ReadOnly);
+  openFileCheckSuccess(QIODevice::ReadOnly, file);
 
   while (!file.atEnd()) {
     QString line = file.readLine().simplified();
@@ -102,7 +120,7 @@ void CDeviceTwoNav::readReginfo(const QString& filename) {
   }
 
   if (!product.isEmpty() && !unittype.isEmpty()) {
-    setText(CGisListWks::eColumnName, QString("%1 (%2)").arg(product, unittype));
+    name = QString("%1 (%2)").arg(product, unittype);
   }
 }
 
