@@ -48,7 +48,7 @@ const QString IGisItem::noName = IGisItem::tr("[no name]");
 
 QVector<IGisItem::color_t> IGisItem::colorMap;
 
-IGisItem::IGisItem(IGisProject* parent, type_e typ, int idx) : QTreeWidgetItem(parent, typ) {
+IGisItem::IGisItem(IGisProject* parent, type_e typ, int idx) : IWksItem(parent, typ) {
   int n = -1;
   setFlags(QTreeWidgetItem::flags() & ~Qt::ItemIsDropEnabled);
 
@@ -123,40 +123,40 @@ IGisItem::IGisItem(IGisProject* parent, type_e typ, int idx) : QTreeWidgetItem(p
 IGisItem::~IGisItem() {}
 
 void IGisItem::init() {
-  colorMap = {{"Black", tr("Black"), QColor(Qt::black), QString("://icons/8x8/bullet_black.png"),
-               QString("://icons/lines/line_black.png")},
-              {"DarkRed", tr("Dark Red"), QColor(Qt::darkRed), QString("://icons/8x8/bullet_dark_red.png"),
-               QString("://icons/lines/line_dark_red.png")},
-              {"DarkGreen", tr("Dark Green"), QColor(Qt::darkGreen), QString("://icons/8x8/bullet_dark_green.png"),
-               QString("://icons/lines/line_dark_green.png")},
-              {"DarkYellow", tr("Dark Yellow"), QColor(Qt::darkYellow), QString("://icons/8x8/bullet_dark_yellow.png"),
-               QString("://icons/lines/line_dark_yellow.png")},
-              {"DarkBlue", tr("Dark Blue"), QColor(Qt::darkBlue), QString("://icons/8x8/bullet_dark_blue.png"),
-               QString("://icons/lines/line_dark_blue.png")},
-              {"DarkMagenta", tr("Dark Magenta"), QColor(Qt::darkMagenta),
-               QString("://icons/8x8/bullet_dark_magenta.png"), QString("://icons/lines/line_dark_magenta.png")},
-              {"DarkCyan", tr("Dark Cyan"), QColor(Qt::darkCyan), QString("://icons/8x8/bullet_dark_cyan.png"),
-               QString("://icons/lines/line_dark_cyan.png")},
-              {"LightGray", tr("Light Gray"), QColor(Qt::lightGray), QString("://icons/8x8/bullet_gray.png"),
-               QString("://icons/lines/line_gray.png")},
-              {"DarkGray", tr("Dark Gray"), QColor(Qt::darkGray), QString("://icons/8x8/bullet_dark_gray.png"),
-               QString("://icons/lines/line_dark_gray.png")},
-              {"Red", tr("Red"), QColor(Qt::red), QString("://icons/8x8/bullet_red.png"),
-               QString("://icons/lines/line_red.png")},
-              {"Green", tr("Green"), QColor(Qt::green), QString("://icons/8x8/bullet_green.png"),
-               QString("://icons/lines/line_green.png")},
-              {"Yellow", tr("Yellow"), QColor(Qt::yellow), QString("://icons/8x8/bullet_yellow.png"),
-               QString("://icons/lines/line_yellow.png")},
-              {"Blue", tr("Blue"), QColor(Qt::blue), QString("://icons/8x8/bullet_blue.png"),
-               QString("://icons/lines/line_blue.png")},
-              {"Magenta", tr("Magenta"), QColor(Qt::magenta), QString("://icons/8x8/bullet_magenta.png"),
-               QString("://icons/lines/line_magenta.png")},
-              {"Cyan", tr("Cyan"), QColor(Qt::cyan), QString("://icons/8x8/bullet_cyan.png"),
-               QString("://icons/lines/line_cyan.png")},
-              {"White", tr("White"), QColor(Qt::white), QString("://icons/8x8/bullet_white.png"),
-               QString("://icons/lines/line_white.png")},
-              {"Transparent", tr("Transparent"), QColor(Qt::transparent), QString(),
-               QString("://icons/lines/line_transparent.png")}};
+  colorMap = {
+      {"Black", tr("Black"), QColor(Qt::black), "://icons/8x8/bullet_black.png", "://icons/lines/line_black.png"},
+      {"DarkRed", tr("Dark Red"), QColor(Qt::darkRed), QString("://icons/8x8/bullet_dark_red.png"),
+       QString("://icons/lines/line_dark_red.png")},
+      {"DarkGreen", tr("Dark Green"), QColor(Qt::darkGreen), QString("://icons/8x8/bullet_dark_green.png"),
+       QString("://icons/lines/line_dark_green.png")},
+      {"DarkYellow", tr("Dark Yellow"), QColor(Qt::darkYellow), QString("://icons/8x8/bullet_dark_yellow.png"),
+       QString("://icons/lines/line_dark_yellow.png")},
+      {"DarkBlue", tr("Dark Blue"), QColor(Qt::darkBlue), QString("://icons/8x8/bullet_dark_blue.png"),
+       QString("://icons/lines/line_dark_blue.png")},
+      {"DarkMagenta", tr("Dark Magenta"), QColor(Qt::darkMagenta), QString("://icons/8x8/bullet_dark_magenta.png"),
+       QString("://icons/lines/line_dark_magenta.png")},
+      {"DarkCyan", tr("Dark Cyan"), QColor(Qt::darkCyan), QString("://icons/8x8/bullet_dark_cyan.png"),
+       QString("://icons/lines/line_dark_cyan.png")},
+      {"LightGray", tr("Light Gray"), QColor(Qt::lightGray), QString("://icons/8x8/bullet_gray.png"),
+       QString("://icons/lines/line_gray.png")},
+      {"DarkGray", tr("Dark Gray"), QColor(Qt::darkGray), QString("://icons/8x8/bullet_dark_gray.png"),
+       QString("://icons/lines/line_dark_gray.png")},
+      {"Red", tr("Red"), QColor(Qt::red), QString("://icons/8x8/bullet_red.png"),
+       QString("://icons/lines/line_red.png")},
+      {"Green", tr("Green"), QColor(Qt::green), QString("://icons/8x8/bullet_green.png"),
+       QString("://icons/lines/line_green.png")},
+      {"Yellow", tr("Yellow"), QColor(Qt::yellow), QString("://icons/8x8/bullet_yellow.png"),
+       QString("://icons/lines/line_yellow.png")},
+      {"Blue", tr("Blue"), QColor(Qt::blue), QString("://icons/8x8/bullet_blue.png"),
+       QString("://icons/lines/line_blue.png")},
+      {"Magenta", tr("Magenta"), QColor(Qt::magenta), QString("://icons/8x8/bullet_magenta.png"),
+       QString("://icons/lines/line_magenta.png")},
+      {"Cyan", tr("Cyan"), QColor(Qt::cyan), QString("://icons/8x8/bullet_cyan.png"),
+       QString("://icons/lines/line_cyan.png")},
+      {"White", tr("White"), QColor(Qt::white), QString("://icons/8x8/bullet_white.png"),
+       QString("://icons/lines/line_white.png")},
+      {"Transparent", tr("Transparent"), QColor(Qt::transparent), QString(),
+       QString("://icons/lines/line_transparent.png")}};
 }
 
 qint32 IGisItem::selectColor(QWidget* parent) {
@@ -221,7 +221,7 @@ void IGisItem::loadFromDb(quint64 id, QSqlDatabase& db) {
   QSqlQuery query(db);
   query.prepare("SELECT data, keyqms, hash FROM items WHERE id=:id");
   query.bindValue(":id", id);
-  QUERY_EXEC(return );
+  QUERY_EXEC(return);
   if (query.next()) {
     QByteArray data(query.value(0).toByteArray());
     QDataStream in(&data, QIODevice::ReadOnly);
@@ -255,7 +255,7 @@ void IGisItem::updateFromDB(quint64 id, QSqlDatabase& db) {
 
   query.prepare("SELECT hash FROM items WHERE id=:id");
   query.bindValue(":id", id);
-  QUERY_EXEC(return );
+  QUERY_EXEC(return);
 
   /*
       Test on the hash stored in the database. If the hash is
@@ -292,8 +292,6 @@ QString IGisItem::getNameEx() const {
 
 void IGisItem::updateDecoration(quint32 enable, quint32 disable) {
   // update text and icon
-  setToolTip(CGisListWks::eColumnName, getInfo(IGisItem::eFeatureShowName));
-  setText(CGisListWks::eColumnName, getName());
   setSymbol();
 
   // update project if necessary
@@ -304,50 +302,11 @@ void IGisItem::updateDecoration(quint32 enable, quint32 disable) {
 
   // test for lost & found folder
   if (project && project->getType() == IGisProject::eTypeLostFound) {
-    setText(CGisListWks::eColumnDecoration, QString());
-    setToolTip(CGisListWks::eColumnDecoration, QString());
     return;
   }
 
   // set marks in column 1
-  quint32 mask = data(1, Qt::UserRole).toUInt();
-  mask |= enable;
-  mask &= ~disable;
-  setData(1, Qt::UserRole, mask);
-
-  QString tt;
-  QString str;
-  if (mask & eMarkNotPart) {
-    tt += tt.isEmpty() ? "" : "\n";
-    tt += tr("The item is not part of the project in the database.");
-    tt += tr("\nIt is either a new item or it has been deleted in the database by someone else.");
-    str += "?";
-  }
-  if (mask & eMarkNotInDB) {
-    tt += tt.isEmpty() ? "" : "\n";
-    tt += tr("The item is not in the database.");
-    str += "X";
-  }
-  if (mask & eMarkChanged) {
-    tt += tt.isEmpty() ? "" : "\n";
-    tt += tr("The item might need to be saved");
-    str += "*";
-  }
-  setText(CGisListWks::eColumnDecoration, str);
-  setToolTip(CGisListWks::eColumnDecoration, tt);
-
-  // Set Rating column
-  if (!keywords.isEmpty()) {
-    QTreeWidgetItem::setIcon(CGisListWks::eColumnRating, QPixmap("://icons/32x32/Tag.png"));
-    setToolTip(CGisListWks::eColumnRating, QStringList(getKeywordsSorted()).join(", "));
-  } else {
-    QTreeWidgetItem::setIcon(CGisListWks::eColumnRating, QIcon());
-  }
-  if (rating > 0) {
-    QTreeWidgetItem::setText(CGisListWks::eColumnRating, QString::number(rating));
-  } else {
-    QTreeWidgetItem::setText(CGisListWks::eColumnRating, "");
-  }
+  IWksItem::updateDecoration(enable, disable);
 }
 
 void IGisItem::changed(const QString& what, const QString& icon) {
@@ -510,7 +469,7 @@ bool IGisItem::isReadOnly() const { return !(flags & eFlagWriteAllowed) || isOnD
 
 bool IGisItem::isTainted() const { return flags & eFlagTainted; }
 
-qint32 IGisItem::isOnDevice() const {
+const qint32 IGisItem::isOnDevice() const {
   IGisProject* project = getParentProject();
   if (nullptr == project) {
     return false;
@@ -596,20 +555,22 @@ void IGisItem::setIcon(const QPixmap& icon) {
 }
 
 void IGisItem::showIcon() {
+  const int& width = icon.width();
+  const int& height = icon.height();
+  // center icon within surrounding square
+  int size = qMax(width, height);
+  displayIcon = QPixmap(size, size);
+  displayIcon.fill(Qt::transparent);
+  QPainter painter(&displayIcon);
+  int dw = (size - width) / 2;
+  int dh = (size - height) / 2;
+  painter.drawPixmap(dw, dh, icon);
   if (isNogo()) {
-    const int& width = icon.width();
-    const int& height = icon.height();
-    displayIcon = QPixmap(width, height);
-    displayIcon.fill(Qt::transparent);
-    QPainter painter(&displayIcon);
-    painter.drawPixmap(0, 0, icon);
-    painter.drawPixmap(width * 0.4, height * 0.4,
+    painter.drawPixmap(width * 0.4 + dw, height * 0.4 + dh,
                        QPixmap("://icons/48x48/NoGo.png")
                            .scaled(width * 0.6, height * 0.6, Qt::KeepAspectRatio, Qt::SmoothTransformation));
-  } else {
-    displayIcon = icon;
   }
-  QTreeWidgetItem::setIcon(CGisListWks::eColumnIcon, displayIcon);
+  icon = displayIcon;
 }
 
 QColor IGisItem::str2color(const QString& name) {
@@ -681,7 +642,10 @@ QString IGisItem::html2Dev(const QString& str, bool strictGpx11) {
     return "";
   }
 
-  return (isOnDevice() == IDevice::eTypeGarmin) || strictGpx11 ? removeHtml(str) : str;
+  return (isOnDevice() == IDevice::eTypeGarmin) || (isOnDevice() == IDevice::eTypeGarminMtp) ||
+                 (isOnDevice() == IDevice::eTypeGenericMtp) || strictGpx11
+             ? removeHtml(str)
+             : str;
 }
 
 QString IGisItem::toLink(bool isReadOnly, const QString& href, const QString& str, const QString& key) {
@@ -758,6 +722,14 @@ QString IGisItem::createText(bool isReadOnly, const QString& desc, const QList<l
   return str;
 }
 
+const bool IGisItem::isVisible() const {
+  IGisProject* project = getParentProject();
+  if (project == nullptr) {
+    return false;
+  }
+  return project->isVisible();
+}
+
 bool IGisItem::isVisible(const QRectF& rect, const QPolygonF& viewport, CGisDraw* gis) {
   QPolygonF tmp1;
   tmp1 << rect.topLeft();
@@ -783,8 +755,6 @@ bool IGisItem::isVisible(const QPointF& point, const QPolygonF& viewport, CGisDr
   return tmp2.boundingRect().contains(pt);
 }
 
-bool IGisItem::isChanged() const { return text(CGisListWks::eColumnDecoration).contains('*'); }
-
 bool IGisItem::isWithin(const QRectF& area, selflags_t flags, const QPolygonF& points) {
   if (points.isEmpty()) {
     return false;
@@ -889,15 +859,11 @@ IGisItem* IGisItem::newGisItem(quint32 type, quint64 id, QSqlDatabase& db, IGisP
   return item;
 }
 
-qreal IGisItem::getRating() const { return rating; }
-
 void IGisItem::setRating(qreal rating) {
   this->rating = rating;
   updateHistory();
 }
 
-const QSet<QString>& IGisItem::getKeywords() const { return keywords; }
-
 QList<QString> IGisItem::getKeywordsSorted() const {
   QList<QString> sortedKeywords = keywords.values();
   std::sort(sortedKeywords.begin(), sortedKeywords.end(), sortByString);
