@@ -16,17 +16,12 @@
 
 **********************************************************************************************/
 
-#include "gis/CGisListDB.h"
 #include "gis/db/CDBFolderGroup.h"
 
 CDBFolderGroup::CDBFolderGroup(QSqlDatabase& db, quint64 key, QTreeWidgetItem* parent)
-    : IDBFolder(false, db, eTypeGroup, key, parent)
-{
-    setIcon(CGisListDB::eColumnCheckbox, QIcon("://icons/32x32/PathBlue.png"));
-    setupFromDB();
-}
-
-CDBFolderGroup::~CDBFolderGroup()
-{
+    : IDBFolder(false, db, eTypeGroup, key, parent) {
+  setIcon(QPixmap("://icons/32x32/PathBlue.png"));
+  setupFromDB();
 }
 
+CDBFolderGroup::~CDBFolderGroup() {}
