@@ -18,11 +18,9 @@
 
 #include "gis/db/CDBFolderOther.h"
 
-#include "gis/CGisListDB.h"
-
 CDBFolderOther::CDBFolderOther(QSqlDatabase& db, quint64 key, QTreeWidgetItem* parent)
     : IDBFolder(true, db, eTypeOther, key, parent) {
-  setIcon(CGisListDB::eColumnCheckbox, QIcon("://icons/32x32/PathOrange.png"));
+  setIcon(QPixmap("://icons/32x32/PathOrange.png"));
   setupFromDB();
 }
 
