@@ -20,13 +20,14 @@
 #define CDBITEM_H
 
 #include <QCoreApplication>
-#include <QTreeWidgetItem>
 #include <QDateTime>
 
+#include "gis/IDBItem.h"
+
 class IDBFolder;
 class QSqlDatabase;
 
-class CDBItem : public QTreeWidgetItem {
+class CDBItem : public IDBItem {
   Q_DECLARE_TR_FUNCTIONS(CDBItem)
  public:
   CDBItem(QSqlDatabase& db, quint64 id, IDBFolder* parent);
@@ -47,8 +48,6 @@ class CDBItem : public QTreeWidgetItem {
    */
   const QString& getKey() const { return key; }
 
-  QString getName() const;
-
   /**
      @brief Send show/hide events to the workspace
    */
