@@ -165,7 +165,8 @@ void CDetailsPrj::slotSetupGui() {
       int idx = tabWidget->indexOf(this);
       if (idx != NOIDX) {
         setObjectName(prj.getName());
-        tabWidget->setTabText(idx, prj.getName().replace("&", "&&"));
+        QString tempName = prj.getName();
+        tabWidget->setTabText(idx, tempName.replace("&", "&&"));
       }
     }
   }
@@ -922,9 +923,10 @@ void CDetailsPrj::slotLinkActivated(const QString& link) {
     }
     prj.setName(name);
   } else if (link == "keywords") {
+    bool ok = false;
     QString keywords = QInputDialog::getText(this, tr("Edit keywords..."), tr("Enter keywords."), QLineEdit::Normal,
-                                             prj.getKeywords());
-    if (keywords.trimmed().isEmpty()) {
+                                             prj.getKeywords(), &ok);
+    if (ok == false) {
       return;
     }
     if (keywords == tr("none")) {
