@@ -114,7 +114,6 @@ CGisItemRte::CGisItemRte(const SGisLine& l, const QString& name, IGisProject* pr
   updateDecoration(eMarkChanged, eMarkNone);
 }
 
-
 CGisItemRte::~CGisItemRte() {
   // reset user focus if focused on this track
   if (key == keyUserFocus) {
@@ -296,7 +295,7 @@ void CGisItemRte::setSymbol() {
 }
 
 void CGisItemRte::setName(const QString& str) {
-  setText(CGisListWks::eColumnName, str);
+  name = str;
   rte.name = str;
   changed(tr("Changed name."), "://icons/48x48/EditText.png");
 }
@@ -432,12 +431,16 @@ bool CGisItemRte::isWithin(const QRectF& area, selflags_t flags) {
   return (flags & eSelectionRte) ? IGisItem::isWithin(area, flags, l) : false;
 }
 
-void CGisItemRte::gainUserFocus(bool yes) { keyUserFocus = yes ? key : key_t(); }
+void CGisItemRte::gainUserFocus(bool yes) {
+  keyUserFocus = yes ? key : key_t();
+  IWksItem::updateItem();
+}
 
 void CGisItemRte::looseUserFocus() {
   if (keyUserFocus == key) {
     keyUserFocus.clear();
   }
+  IWksItem::updateItem();
 }
 
 void CGisItemRte::drawItem(QPainter& p, const QPolygonF& viewport, QList<QRectF>& blockedAreas, CGisDraw* gis) {
@@ -827,7 +830,6 @@ void CGisItemRte::setResultFromRoutino(Routino_Output* route, const QString& opt
 
   rte.lastRoutedTime = QDateTime::currentDateTimeUtc();
   rte.lastRoutedWith = "Routino, " + options;
-  rte.cmt = ""; // Cleanup possible BRouter comment
 
   deriveSecondaryData();
   updateHistory();
@@ -838,7 +840,26 @@ void CGisItemRte::setResultFromBRouter(const QDomDocument& xml, const QString& o
 
   rte.totalDistance = 0.;
   rte.totalTime = 0;
-  rte.cmt = ""; 
+
+  quint32 totalTime = 0;
+  const QDomNodeList& nodes = xml.childNodes();
+  for (int i = 0; i < nodes.count(); i++) {
+    const QDomNode& node = nodes.at(i);
+    if (node.isComment()) {
+      const QString& comment = node.toComment().data();
+      // ' track-length = 3181 filtered ascend = 70 plain-ascend = 5 cost=8491 energy=.0kwh time=16m 30s '
+      // BRouter <= 1.7.8 does not set start point's time extension for route without intermediate points,
+      // use comment's time as workaround!
+      const QRegularExpressionMatch& match =
+          QRegularExpression("time\\s*=\\s*((\\d+)(?:h ))?((\\d+)(?:m ))?((\\d+)(?:s))").match(comment);
+      if (match.hasMatch()) {
+        totalTime += match.captured(2).toUInt() * 3600;
+        totalTime += match.captured(4).toUInt() * 60;
+        totalTime += match.captured(6).toUInt();
+      }
+      break;
+    }
+  }
 
   QVector<subpt_t> shape;
 
@@ -856,9 +877,9 @@ void CGisItemRte::setResultFromBRouter(const QDomDocument& xml, const QString& o
     subpt.lat = elem.attribute("lat").toDouble();
     subpt.ele = elem.firstChildElement("ele").text().toDouble();
     if (n > 0) {
-      const subpt_t& other = shape[n-1];
-      rte.totalDistance += GPS_Math_Distance(subpt.lon * DEG_TO_RAD, subpt.lat * DEG_TO_RAD,
-                                             other.lon * DEG_TO_RAD, other.lat * DEG_TO_RAD);
+      const subpt_t& other = shape[n - 1];
+      rte.totalDistance += GPS_Math_Distance(subpt.lon * DEG_TO_RAD, subpt.lat * DEG_TO_RAD, other.lon * DEG_TO_RAD,
+                                             other.lat * DEG_TO_RAD);
     }
     subpt.distance = rte.totalDistance;
   }
@@ -890,89 +911,75 @@ void CGisItemRte::setResultFromBRouter(const QDomDocument& xml, const QString& o
       subpt.instruction = xmlManeuver.firstChildElement("desc").text();
       const QString& command = extension.firstChildElement("turn").text();
       // commands see at https://github.com/abrensch/brouter/blob/master/docs/features/voicehints.md
-      if (command == "C")
-      {
+      if (command == "C") {
         subpt.bearing = 0;
         subpt.instruction = tr("Go straight");
-      } else if (command == "TL")
-      {
+      } else if (command == "TL") {
         subpt.bearing = -90;
         subpt.instruction = tr("Turn left");
-      } else if (command == "TSLL")
-      {
+      } else if (command == "TSLL") {
         subpt.bearing = -45;
         subpt.instruction = tr("Turn slightly left");
-      } else if (command == "TSHL")
-      {
+      } else if (command == "TSHL") {
         subpt.bearing = -135;
         subpt.instruction = tr("Turn sharply left");
-      } else if (command == "TR")
-      {
+      } else if (command == "TR") {
         subpt.bearing = 90;
         subpt.instruction = tr("Turn right");
-      } else if (command == "TSLR")
-      {
+      } else if (command == "TSLR") {
         subpt.bearing = 45;
         subpt.instruction = tr("Turn slightly right");
-      } else if (command == "TSHR")
-      {
+      } else if (command == "TSHR") {
         subpt.bearing = 135;
         subpt.instruction = tr("Turn sharply right");
-      } else if (command == "KL")
-      {
+      } else if (command == "KL") {
         subpt.bearing = 0;
         subpt.instruction = tr("Keep left");
-      } else if (command == "KR")
-      {
+      } else if (command == "KR") {
         subpt.bearing = 0;
         subpt.instruction = tr("Keep right");
-      } else if (command == "TLU")
-      {
+      } else if (command == "TLU") {
         subpt.bearing = -180;
         subpt.instruction = tr("U-turn left");
-      } else if (command == "TU")
-      {
+      } else if (command == "TU") {
         subpt.bearing = 180;
         subpt.instruction = tr("U-turn");
-      } else if (command == "TRU")
-      {
+      } else if (command == "TRU") {
         subpt.bearing = 180;
         subpt.instruction = tr("U-turn right");
-      } else if (command.startsWith("RNDB"))
-      {
+      } else if (command.startsWith("RNDB")) {
         subpt.bearing = 0;
         subpt.instruction = tr("Roundabout exit %1").arg(command.mid(4));
-      } else if (command.startsWith("RNLB"))
-      {
+      } else if (command.startsWith("RNLB")) {
         subpt.bearing = 0;
         subpt.instruction = tr("Roundabout left exit %1").arg(command.mid(4));
-      } else if (command == "EL")
-      {
+      } else if (command == "EL") {
         subpt.bearing = 0;
         subpt.instruction = tr("Exit left");
-      } else if (command == "ER")
-      {
+      } else if (command == "ER") {
         subpt.bearing = 0;
         subpt.instruction = tr("Exit right");
-      } else if (subpt.instruction == "start")
-      {
+      } else if (subpt.instruction == "start") {
         subpt.instruction = tr("Start");
-      } else if (subpt.instruction == "destination")
-      {
+      } else if (subpt.instruction == "destination") {
         subpt.instruction = tr("Destination");
       }
-      subpt.turn = xmlManeuver.firstChildElement("extensions").firstChildElement("turn-angle").text().toInt();
+      subpt.turn = extension.firstChildElement("turn-angle").text().toInt();
       if (subpt.turn != 0) {
         subpt.instruction += tr(", %1 degrees").arg(subpt.turn);
       }
       subpt.time = time.addSecs(rte.totalTime);
-      rte.totalTime += xmlManeuver.firstChildElement("extensions").firstChildElement("time").text().toUInt();
+      const QDomElement& timeElement = extension.firstChildElement("time");
+      if (!timeElement.isNull()) {
+        rte.totalTime += timeElement.text().toUInt();
+      } else if (m == 0) {
+        rte.totalTime = totalTime;  // use time workaround for start
+      }
       if (prevIdx != -1) {
         subpt_t& other = shape[prevIdx];
         IUnit::self().meter2distance(subpt.distance - other.distance, valDist, unitDist);
         IUnit::self().seconds2time(other.time.secsTo(subpt.time), valTime, unitTime);
-        other.instruction += "\n" + tr("Follow the route for %1%2 or %3%4")
-            .arg(valDist, unitDist, valTime, unitTime);
+        other.instruction += "\n" + tr("Follow the route for %1%2 or %3%4").arg(valDist, unitDist, valTime, unitTime);
       }
       prevIdx = idx;
     }
@@ -1013,21 +1020,6 @@ void CGisItemRte::setResultFromBRouter(const QDomDocument& xml, const QString& o
   rte.lastRoutedTime = QDateTime::currentDateTimeUtc();
   rte.lastRoutedWith = QString("BRouter %1").arg(options);
 
-  //  <!-- track-length = 3181 filtered ascend = 70 plain-ascend = 5 cost=8491 energy=.0kwh time=16m 30s -->
-  const QDomNodeList& nodes = xml.childNodes();
-  for (int i = 0; i < nodes.count(); i++) {
-    const QDomNode& node = nodes.at(i);
-    if (node.isComment()) {
-      const QString& commentTxt = node.toComment().data();
-      // ' track-length = 3181 filtered ascend = 70 plain-ascend = 5 cost=8491 energy=.0kwh time=16m 30s '
-      const QRegularExpressionMatch& match = QRegularExpression("(filtered.*)(?:\\s+time)").match(commentTxt);
-      if (match.hasMatch()) {
-        rte.cmt = match.captured(1).replace(QRegularExpression("\\s*=\\s*"), "=");
-      }
-      break;
-    }
-  }
-
   deriveSecondaryData();
   updateHistory();
 }
@@ -1068,7 +1060,7 @@ QMap<searchProperty_e, CGisItemRte::fSearch> CGisItemRte::initKeywordLambdaMap()
   });
   map.insert(eSearchPropertyGeneralKeywords, [](CGisItemRte* item) {
     searchValue_t searchValue;
-    searchValue.str1 = QStringList(item->getKeywords().values()).join(", ");
+    searchValue.str1 = QStringList(item->getTags().values()).join(", ");
     return searchValue;
   });
   map.insert(eSearchPropertyGeneralType, [](CGisItemRte* item) {
