@@ -42,7 +42,7 @@ class CRouterBRouterTilesSelect : public QWidget {
   void initialize();
   void cancelDownload() const;
 
-  static QString formatSize(const qint64 size);
+  static QString formatSize(const quint64 size);
   static QPoint tileFromFileName(const QString& fileName);
   static QString fileNameFromTile(const QPoint tile);
 
@@ -59,9 +59,9 @@ class CRouterBRouterTilesSelect : public QWidget {
   static const QString patternTileName;
   static const QString patternDate;
   static const QString patternSize;
-  static const QRegExp regExpTileName;
-  static const QRegExp regExpDate;
-  static const QRegExp regExpSize;
+  static const QRegularExpression regExpTileName;
+  static const QRegularExpression regExpDate;
+  static const QRegularExpression regExpSize;
   static const QString formatDate;
   static const QLocale localeDate;
 
