@@ -33,7 +33,7 @@ class CTcxProject : public IGisProject {
 
   const QString getFileExtension() const override { return "tcx"; }
 
-  bool canSave() const override { return true; }
+  const bool canSave() const override { return true; }
 
   static bool saveAs(const QString& fn, IGisProject& project);
 
