@@ -26,6 +26,7 @@
 #include "gis/CGisDraw.h"
 #include "gis/CGisWorkspace.h"
 #include "gis/GeoMath.h"
+#include "gis/ovl/CGisItemOvlArea.h"
 #include "gis/prj/IGisProject.h"
 #include "gis/proj_x.h"
 #include "gis/rte/CGisItemRte.h"
@@ -35,6 +36,7 @@
 #include "gis/trk/CKnownExtension.h"
 #include "gis/trk/CPropertyTrk.h"
 #include "gis/trk/CScrOptTrk.h"
+#include "gis/trk/CTrkToAreaDialog.h"
 #include "gis/trk/CTrkToRteDialog.h"
 #include "gis/wpt/CGisItemWpt.h"
 #include "helpers/CDraw.h"
@@ -227,12 +229,11 @@ CGisItemTrk::CGisItemTrk(CTrackData& trkdata, IGisProject* project)
   checkForInvalidPoints();
 }
 
-
 CGisItemTrk::~CGisItemTrk() {
   // reset user focus if focused on this track
   if (key == keyUserFocus) {
-  keyUserFocus.clear();
-}
+    keyUserFocus.clear();
+  }
 
   /*
       Delete all registered INotifyTrk as they can't exist without the item.
@@ -645,7 +646,7 @@ QString CGisItemTrk::getInfoProgress(const CTrackData::trkpt_t& pt) const {
 
   if (pt.descent != NOFLOAT) {
     IUnit::self().meter2elevation(pt.descent, val, unit);
-    qreal  slope = totalDescent ? (pt.descent * 100 / totalDescent) : 0;
+    qreal slope = totalDescent ? (pt.descent * 100 / totalDescent) : 0;
     dsc = tr("Descent: %1%2 (%3%)").arg(val, unit).arg(slope, 2, 'f', 0);
   }
 
@@ -1064,14 +1065,12 @@ void CGisItemTrk::deriveSecondaryData() {
   //    qDebug() << "totalElapsedSecondsMoving" << totalElapsedSecondsMoving;
 }
 
-void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& current) {
+void CGisItemTrk::findWaypointsCloseBy() {
   IGisProject* project = getParentProject();
   if (nullptr == project) {
     return;
   }
 
-  quint32 lastCurrent = current;
-
   bool withDoubles = project->getSortingRoadbook() != IGisProject::eSortRoadbookTrackWithoutDouble;
 
   qreal north = -90 * DEG_TO_RAD;
@@ -1143,7 +1142,6 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
     qint32 index = NOIDX;
 
     for (const pointDP& pt : std::as_const(line)) {
-      ++current;
       qreal d = (trkwpt.x - pt.x) * (trkwpt.x - pt.x) + (trkwpt.y - pt.y) * (trkwpt.y - pt.y);
 
       if (d < WPT_FOCUS_DIST_IN) {
@@ -1165,11 +1163,6 @@ void CGisItemTrk::findWaypointsCloseBy(CProgressDialog& progress, quint32& curre
         index = NOIDX;
         minD = WPT_FOCUS_DIST_IN;
       }
-
-      if (current - lastCurrent > 100) {
-        lastCurrent = current;
-        PROGRESS(current, return );
-      }
     }
 
     if (index != NOIDX) {
@@ -1206,12 +1199,14 @@ bool CGisItemTrk::isWithin(const QRectF& area, selflags_t flags) {
 void CGisItemTrk::gainUserFocus(bool yes) {
   keyUserFocus = yes ? key : key_t();
   widthInfoBox = MIN_WIDTH_INFO_BOX;
+  IWksItem::updateItem();
 }
 
 void CGisItemTrk::looseUserFocus() {
   if (keyUserFocus == key) {
     keyUserFocus.clear();
   }
+  IWksItem::updateItem();
 }
 
 void CGisItemTrk::edit() {
@@ -2154,7 +2149,7 @@ bool CGisItemTrk::setMode(mode_e m, const QString& owner) {
 }
 
 void CGisItemTrk::setName(const QString& str) {
-  setText(CGisListWks::eColumnName, str);
+  name = str;
   trk.name = str;
   changed(tr("Changed name"), "://icons/48x48/EditText.png");
 }
@@ -2772,7 +2767,7 @@ QMap<searchProperty_e, CGisItemTrk::fSearch> CGisItemTrk::initKeywordLambdaMap()
   });
   map.insert(eSearchPropertyGeneralKeywords, [](CGisItemTrk* item) {
     searchValue_t searchValue;
-    searchValue.str1 = QStringList(item->getKeywords().values()).join(", ");
+    searchValue.str1 = QStringList(item->getTags().values()).join(", ");
     return searchValue;
   });
   map.insert(eSearchPropertyGeneralType, [](CGisItemTrk* item) {
@@ -2877,3 +2872,31 @@ void CGisItemTrk::toRoute() {
 
   new CGisItemRte(points, routeName, project, NOIDX);
 }
+
+void CGisItemTrk::toArea() {
+  qint32 idx1, idx2;
+  QString areaName;
+  IGisProject* project = getParentProject();
+
+  if (nullptr == project) {
+    qCritical("CGisItemTrk::toArea no project");
+    return;
+  }
+  getMouseRange(idx1, idx2, true);
+
+  if (NOIDX == idx1) {
+    areaName = getName();
+  } else {
+    areaName = getName() + QString(" (%1-%2)").arg(idx1).arg(idx2);
+  }
+
+  CTrkToAreaDialog dlg(project, areaName);
+  if (dlg.exec() == QDialog::Rejected) {
+    return;
+  }
+
+  SGisLine points;
+  getPolylineRangeFromData(points, idx1, idx2, true);
+
+  new CGisItemOvlArea(points, areaName, project, NOIDX);
+}
