@@ -1412,7 +1412,7 @@ void CWptIconManager::init() {
       {tr("traditional cache")}
     },
     {
-      {16,16}, "Multi-Cache", "://icons/geocaching/icons/multi.png",
+      {16,16}, "Multi-cache", "://icons/geocaching/icons/multi.png",
       {tr("geocache")},
       {tr("multi cache")}
     },
@@ -1421,11 +1421,31 @@ void CWptIconManager::init() {
       {tr("geocache")},
       {tr("unknown cache")}
     },
+    {
+      {16,16}, "Letterbox Hybrid", "://icons/geocaching/icons/letterbox.png",
+      {tr("geocache")},
+      {tr("letterbox cache")}
+    },
     {
       {16,16}, "Wherigo Cache", "://icons/geocaching/icons/wherigo.png",
       {tr("geocache")},
       {tr("wherigo cache")}
     },
+    {
+      {16,16}, "Earthcache", "://icons/geocaching/icons/earth.png",
+      {tr("geocache")},
+      {tr("earthcache")}
+    },
+    {
+      {16,16}, "Virtual Cache", "://icons/geocaching/icons/virtual.png",
+      {tr("geocache")},
+      {tr("virtual cache")}
+    },
+    {
+      {16,16}, "Webcam Cache", "://icons/geocaching/icons/webcam.png",
+      {tr("geocache")},
+      {tr("webcam cache")}
+    },
     {
       {16,16}, "Event Cache", "://icons/geocaching/icons/event.png",
       {tr("geocache")},
@@ -1447,33 +1467,37 @@ void CWptIconManager::init() {
       {tr("cache in trash out event")}
     },
     {
-      {16,16}, "Earthcache", "://icons/geocaching/icons/earth.png",
+      {16,16}, "Final Location", "://icons/32x32/waypoint_final.png",
       {tr("geocache")},
-      {tr("earthcache")}
+      {tr("Final Location")}
     },
     {
-      {16,16}, "Letterbox Cache", "://icons/geocaching/icons/letterbox.png",
+      {16,16}, "Physical Stage", "://icons/32x32/waypoint_physical.png",
       {tr("geocache")},
-      {tr("letterbox cache")}
+      {tr("Physical Stage")}
     },
     {
-      {16,16}, "Virtual Cache", "://icons/geocaching/icons/virtual.png",
+      {16,16}, "Reference Point", "://icons/32x32/waypoint_reference.png",
       {tr("geocache")},
-      {tr("virtual cache")}
+      {tr("Reference Waypoint")}
     },
     {
-      {16,16}, "Webcam Cache", "://icons/geocaching/icons/webcam.png",
+      {16,16}, "Trailhead", "://icons/32x32/waypoint_trailhead.png",
       {tr("geocache")},
-      {tr("webcam cache")}
+      {tr("Trailhead")}
+    },
+    {
+      {16,16}, "Virtual Stage", "://icons/32x32/waypoint_virtual.png",
+      {tr("geocache")},
+      {tr("Virtual Stage")}
     },
-
     {
       {16,16}, "gray_Traditional Cache", "://icons/geocaching/icons/gray_Traditional Cache.png",
       {tr("geocache")},
       {tr("traditional cache")}
     },
     {
-      {16,16}, "gray_Multi-Cache", "://icons/geocaching/icons/gray_Multi-Cache.png",
+      {16,16}, "gray_Multi-cache", "://icons/geocaching/icons/gray_Multi-Cache.png",
       {tr("geocache")},
       {tr("multi cache")}
     },
@@ -1527,7 +1551,6 @@ void CWptIconManager::init() {
       {tr("geocache")},
       {tr("webcam cache")}
     },
-
     {
       {16,16}, "Contact, Afro", "://icons/waypoints/32x32/ContactAfro.png",
       {tr("contact")},
