@@ -20,25 +20,20 @@
 #define SIGNALS_H
 
 #include <QObject>
-#include <QRegExp>
+#include <QRegularExpression>
 
-inline void X______________BlockAllSignals______________X(QObject* parent)
-{
-    const QList<QObject*>& children = parent->findChildren<QObject*>(QRegExp(".*"));
-    for(QObject* obj : children)
-    {
-        obj->blockSignals(true);
-    }
+inline void X______________BlockAllSignals______________X(QObject* parent) {
+  const QList<QObject*>& children = parent->findChildren<QObject*>(QRegularExpression(".*"));
+  for (QObject* obj : children) {
+    obj->blockSignals(true);
+  }
 }
 
-inline void X_____________UnBlockAllSignals_____________X(QObject* parent)
-{
-    const QList<QObject*>& children = parent->findChildren<QObject*>(QRegExp(".*"));
-    for(QObject* obj : children)
-    {
-        obj->blockSignals(false);
-    }
+inline void X_____________UnBlockAllSignals_____________X(QObject* parent) {
+  const QList<QObject*>& children = parent->findChildren<QObject*>(QRegularExpression(".*"));
+  for (QObject* obj : children) {
+    obj->blockSignals(false);
+  }
 }
 
-#endif //SIGNALS_H
-
+#endif  // SIGNALS_H
