@@ -21,11 +21,19 @@
 
 #include "CMainWindow.h"
 #include "CSingleInstanceProxy.h"
+#include "helpers/CSettings.h"
 #include "setup/CAppOpts.h"
 #include "setup/IAppSetup.h"
 #include "version.h"
 
 int main(int argc, char** argv) {
+  // preserve "original" argument list
+  int argCnt = argc;
+  char** argVal = new char*[argCnt];
+  for (int i = 0; i < argCnt; i++) {
+    argVal[i] = argv[i];
+  }
+
   QApplication app(argc, argv);
 
   QCoreApplication::setApplicationName("QMapShack");
@@ -36,6 +44,21 @@ int main(int argc, char** argv) {
   IAppSetup* env = IAppSetup::getPlatformInstance();
   env->processArguments();
   env->initLogHandler();
+
+  // useful debug info
+  {
+    qDebug().nospace() << "Qt versions: " << "build=" << QT_VERSION_STR << ", runtime=" << qVersion();
+    QString argList("");
+    for (int i = 1; i < argCnt; i++) {
+      argList += " \"" + QString(argVal[i]) + "\"";
+    }
+    qDebug() << "Executable path:" << QFileInfo(argVal[0]).absoluteFilePath();
+    qDebug().noquote().nospace() << "Argument list:" << argList;
+    SETTINGS;
+    qDebug() << "Configuration path:" << cfg.fileName();
+  }
+  delete[] argVal;
+
   env->initQMapShack();
 
   // setup default proxy
@@ -44,7 +67,7 @@ int main(int argc, char** argv) {
   // make sure this is the one and only instance on the system
   CSingleInstanceProxy s(qlOpts->arguments);
 
-  QSplashScreen* splash = nullptr;
+  QPointer<QSplashScreen> splash = nullptr;
   if (!qlOpts->nosplash) {
     QPixmap pic(":/pics/splash.png");
     QPainter p(&pic);
@@ -56,6 +79,7 @@ int main(int argc, char** argv) {
     p.drawText(550, 395, "V " VER_STR);
 
     splash = new QSplashScreen(pic);
+    splash->setWindowFlags(splash->windowFlags() | Qt::WindowStaysOnTopHint);
 #ifdef Q_OS_MAC
     // remove the splash screen flag on OS-X as workaround for the reported bug
     // https://bugreports.qt.io/browse/QTBUG-49576
@@ -68,8 +92,12 @@ int main(int argc, char** argv) {
   w.show();
 
   if (nullptr != splash) {
-    splash->finish(&w);
-    delete splash;
+    QTimer::singleShot(1500, splash, [splash, &w]() {
+      if (!splash.isNull()) {
+        splash->finish(&w);
+        delete splash;
+      }
+    });
   }
 
   return app.exec();
