@@ -325,11 +325,10 @@ void CMapDraw::loadMapList(QSettings& cfg) {
   QList<CMapItem*> mapsUnknown = mapsFound.values();
   std::sort(mapsUnknown.begin(), mapsUnknown.end(), &sortByName<CMapItem>);
   for (CMapItem* map : mapsUnknown) {
-    map->setStatus(CMapItemWidget::eStatus::Unused);
-
     QFileInfo fi(map->getFilename());
     maps << fi.completeBaseName();
     mapList->addMap(map);
+    map->setStatus(IMapItem::eStatus::Unused);
   }
 
   // ------------- stat --------------
@@ -405,7 +404,9 @@ void CMapDraw::drawt(IDrawContext::buffer_t& currentBuffer) /* override */
         continue;
       }
 
+      item->setProcessing(true);
       item->getMapfile()->draw(currentBuffer);
+      item->setProcessing(false);
       seenActiveMap = true;
     }
   }
