@@ -23,21 +23,46 @@
 #include "CMainWindow.h"
 #include "map/CMapDraw.h"
 #include "map/CMapItem.h"
+#include "map/CMapItemDelegate.h"
 #include "misc.h"
 
+CMapTreeWidget::CMapTreeWidget(QWidget* parent) : QTreeWidget(parent) {
+  CMapItemDelegate* delegate = new CMapItemDelegate(this);
+  setItemDelegate(delegate);
+  QObject::connect(delegate, &CMapItemDelegate::sigUpdateItem, this, &CMapTreeWidget::slotUpdateItem);
+}
+
+void CMapTreeWidget::slotUpdateItem(const QString& key) {
+  const int N = topLevelItemCount();
+  for (int n = 0; n < N; n++) {
+    CMapItem* map = dynamic_cast<CMapItem*>(topLevelItem(n));
+    if (map == nullptr || map->getKey() != key) {
+      continue;
+    }
+    viewport()->update(visualItemRect(map));
+    break;
+  }
+}
+
 void CMapTreeWidget::dragEnterEvent(QDragEnterEvent* e) {
   collapseAll();
+  CMapItem* item = dynamic_cast<CMapItem*>(currentItem());
+  if (item) {
+    setItemWidget(item, 0, nullptr);
+  }
   QTreeWidget::dragEnterEvent(e);
 }
 
-void CMapTreeWidget::dragMoveEvent(QDragMoveEvent* e) {
-  CMapItem* item = dynamic_cast<CMapItem*>(itemAt(e->pos()));
+void CMapTreeWidget::dragLeaveEvent(QDragLeaveEvent* e) {
+  CMapItem* item = dynamic_cast<CMapItem*>(currentItem());
+  if (item) {
+    item->showChildren(false);
+  }
 
-  if (item && item->isActivated()) {
-    e->setDropAction(Qt::MoveAction);
-    QTreeWidget::dragMoveEvent(e);
-  } else {
-    e->setDropAction(Qt::IgnoreAction);
+  QTreeWidget::dragLeaveEvent(e);
+
+  if (item) {
+    item->showChildren(true);
   }
 }
 
@@ -53,6 +78,7 @@ void CMapTreeWidget::dropEvent(QDropEvent* e) {
     item->showChildren(true);
   }
 
+  setCurrentItem(nullptr);
   emit sigChanged();
 }
 
@@ -62,45 +88,33 @@ CMapList::CMapList(QWidget* parent) : QWidget(parent) {
 
   connect(treeWidget, &CMapTreeWidget::customContextMenuRequested, this, &CMapList::slotContextMenu);
   connect(treeWidget, &CMapTreeWidget::sigChanged, this, &CMapList::sigChanged);
-  connect(actionActivate, &QAction::triggered, this, &CMapList::slotActivate);
   connect(actionMoveUp, &QAction::triggered, this, &CMapList::slotMoveUp);
   connect(actionMoveDown, &QAction::triggered, this, &CMapList::slotMoveDown);
+  connect(actionRemove, &QAction::triggered, this, &CMapList::slotRemove);
   connect(actionReloadMaps, &QAction::triggered, this, &CMapList::slotReloadMaps);
   connect(labelHelpFillMapList, &QLabel::linkActivated, &CMainWindow::self(),
           static_cast<void (CMainWindow::*)(const QString&)>(&CMainWindow::slotLinkActivated));
   connect(lineFilter, &QLineEdit::textChanged, this, &CMapList::slotFilter);
 
   menu = new QMenu(this);
-  menu->addAction(actionActivate);
   menu->addAction(actionMoveUp);
   menu->addAction(actionMoveDown);
   menu->addSeparator();
+  menu->addAction(actionRemove);
+  menu->addSeparator();
   menu->addAction(actionReloadMaps);
   menu->addAction(CMainWindow::self().getMapSetupAction());
 }
 
 CMapList::~CMapList() {}
 
-void CMapList::clear() { treeWidget->clear(); }
-
-void CMapList::sort() {
-  QList<CMapItem*> items1;
-  while (treeWidget->topLevelItemCount()) {
-    CMapItem* item = dynamic_cast<CMapItem*>(treeWidget->takeTopLevelItem(0));
-    if (item != nullptr) {
-      items1 << item;
-    }
-  }
-
-  std::sort(items1.begin(), items1.end(), &sortByName<CMapItem>);
-
-  QList<QTreeWidgetItem*> items2;
-  for (CMapItem* item : qAsConst(items1)) {
-    items2 << item;
-  }
-  treeWidget->addTopLevelItems(items2);
+void CMapList::addMap(CMapItem* map) {
+  treeWidget->addTopLevelItem(map);
+  connect(map, &CMapItem::sigChanged, this, &CMapList::sigChanged);
 }
 
+void CMapList::clear() { treeWidget->clear(); }
+
 int CMapList::count() { return treeWidget->topLevelItemCount(); }
 
 CMapItem* CMapList::item(int i) { return dynamic_cast<CMapItem*>(treeWidget->topLevelItem(i)); }
@@ -114,26 +128,33 @@ void CMapList::updateHelpText() {
     labelIcon->show();
     labelHelpActivateMap->hide();
   } else {
-    CMapItem* item = dynamic_cast<CMapItem*>(treeWidget->topLevelItem(0));
+    bool showHelp = true;
 
-    bool showHelp = !(item && item->isActivated());
+    const int N = treeWidget->topLevelItemCount();
+    for (int n = 0; n < N; n++) {
+      CMapItem* map = dynamic_cast<CMapItem*>(treeWidget->topLevelItem(n));
+      if (map == nullptr) {
+        continue;
+      }
+      if (map->isActivated()) {
+        showHelp = false;
+      }
+    }
     labelIcon->setVisible(showHelp);
     labelHelpActivateMap->setVisible(showHelp);
   }
 }
 
-void CMapList::slotActivate() {
-  CMapItem* item = dynamic_cast<CMapItem*>(treeWidget->currentItem());
-  if (nullptr == item) {
+void CMapList::moveMapToTop(CMapItem* map) {
+  const int index = treeWidget->indexOfTopLevelItem(map);
+  if (index == NOIDX) {
     return;
   }
-
-  bool activated = item->toggleActivate();
-  if (!activated) {
-    treeWidget->setCurrentItem(0);
-  }
-
-  updateHelpText();
+  map->showChildren(false);
+  treeWidget->setItemWidget(map, 0, nullptr);
+  treeWidget->takeTopLevelItem(index);
+  treeWidget->insertTopLevelItem(0, map);
+  map->showChildren(true);
 }
 
 void CMapList::slotMoveUp() {
@@ -148,6 +169,7 @@ void CMapList::slotMoveUp() {
   }
 
   item->showChildren(false);
+  treeWidget->setItemWidget(item, 0, nullptr);
   treeWidget->takeTopLevelItem(index);
   treeWidget->insertTopLevelItem(index - 1, item);
   item->showChildren(true);
@@ -167,6 +189,7 @@ void CMapList::slotMoveDown() {
   }
 
   item->showChildren(false);
+  treeWidget->setItemWidget(item, 0, nullptr);
   treeWidget->takeTopLevelItem(index);
   treeWidget->insertTopLevelItem(index + 1, item);
   item->showChildren(true);
@@ -174,34 +197,39 @@ void CMapList::slotMoveDown() {
   emit treeWidget->sigChanged();
 }
 
+void CMapList::slotRemove() {
+  CMapItem* item = dynamic_cast<CMapItem*>(treeWidget->currentItem());
+  if (item == nullptr) {
+    return;
+  }
+
+  int index = treeWidget->indexOfTopLevelItem(item);
+  if (index == NOIDX) {
+    return;
+  }
+
+  delete treeWidget->takeTopLevelItem(index);
+}
+
 void CMapList::slotContextMenu(const QPoint& point) {
   CMapItem* item = dynamic_cast<CMapItem*>(treeWidget->currentItem());
 
   bool itemIsSelected = nullptr != item;
-  bool itemIsActivated = item ? item->isActivated() : false;
 
-  actionActivate->setEnabled(itemIsSelected);
-  actionMoveUp->setEnabled(itemIsSelected);
-  actionMoveDown->setEnabled(itemIsSelected);
+  actionMoveUp->setEnabled(itemIsSelected && (treeWidget->itemAbove(item) != 0));
+  actionMoveDown->setEnabled(itemIsSelected && (treeWidget->itemBelow(item) != 0));
+  actionRemove->setVisible(itemIsSelected && item->getStatus() == IMapItem::eStatus::Missing);
 
-  actionActivate->setChecked(itemIsActivated);
-  actionActivate->setText(itemIsActivated ? tr("Deactivate") : tr("Activate"));
-
-  if (itemIsSelected) {
-    CMapItem* item1 = dynamic_cast<CMapItem*>(treeWidget->itemBelow(item));
-    actionMoveUp->setEnabled(itemIsActivated && (treeWidget->itemAbove(item) != 0));
-    actionMoveDown->setEnabled(itemIsActivated && item1 && item1->isActivated());
-  }
   QPoint p = treeWidget->mapToGlobal(point);
   menu->exec(p);
 }
 
 static void saveResource(const QString& name, QDir& dir) {
   QFile resource1(QString("://map/%1").arg(name));
-  resource1.open(QIODevice::ReadOnly);
+  openFileCheckSuccess(QIODevice::ReadOnly, resource1);
 
   QFile file(dir.absoluteFilePath(name));
-  file.open(QIODevice::WriteOnly);
+  openFileCheckSuccess(QIODevice::WriteOnly, file);
   file.write(resource1.readAll());
   file.close();
 }
@@ -234,7 +262,13 @@ void CMapList::slotMapHonk() {
   }
 }
 
-void CMapList::slotReloadMaps() { CMapDraw::setupMapPath(CMapDraw::getMapPaths()); }
+void CMapList::slotReloadMaps() {
+  CMapItemDelegate* delegate = dynamic_cast<CMapItemDelegate*>(treeWidget->itemDelegate());
+  if (delegate != nullptr) {
+    delegate->reset();
+  }
+  CMapDraw::setupMapPath(CMapDraw::getMapPaths());
+}
 
 void CMapList::slotFilter(const QString& str) {
   actionClearFilter->setIcon(str.isEmpty() ? QIcon("://icons/32x32/Filter.png") : QIcon("://icons/32x32/Cancel.png"));
