@@ -21,12 +21,11 @@
 
 #include "IGarminStrTbl.h"
 
-class CGarminStrTbl8 : public IGarminStrTbl
-{
-public:
-    CGarminStrTbl8(const quint16 codepage, const quint8 mask, QObject* parent);
-    virtual ~CGarminStrTbl8();
+class CGarminStrTbl8 : public IGarminStrTbl {
+ public:
+  CGarminStrTbl8(const quint16 codepage, const quint8 mask, QObject* parent);
+  virtual ~CGarminStrTbl8();
 
-    void get(CFileExt& file, quint32 offset, type_e t, QStringList& info) override;
+  void get(CFileExt& file, quint32 offset, type_e t, QStringList& info) override;
 };
-#endif                           //CGARMINSTRTBL8_H
+#endif  // CGARMINSTRTBL8_H
