@@ -16,31 +16,38 @@
 
 **********************************************************************************************/
 
-#include "CAppSetupLinux.h"
+#include <QtSystemDetection>
+#if defined(Q_OS_LINUX) || defined(Q_OS_FREEBSD) || defined(__FreeBSD_kernel__) || defined(__GNU__)
+
+#include "setup/CAppSetupLinux.h"
+
+#include <QWindow>
+
+#include "signal.h"
+#include "unistd.h"
 
 #include "config.h"
 #include "version.h"
 
-#ifndef _MKSTR_1
-#define _MKSTR_1(x) #x
-#define _MKSTR(x) _MKSTR_1(x)
-#endif
-
 void CAppSetupLinux::initQMapShack() {
-  prepareGdal("", "");
+  // setup gdal
+  prepareGdal("", "", "");
 
   // setup translators
-  QString resourceDir = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
+  const QString& resourceDir = QLibraryInfo::path(QLibraryInfo::TranslationsPath);
   QString translationPath = QCoreApplication::applicationDirPath();
   static const QRegularExpression re("bin$");
   translationPath.replace(re, "share/qmapshack/translations");
-  prepareTranslator(resourceDir, "qt_");
+  prepareTranslator(resourceDir, "qtbase_");
   prepareTranslator(translationPath, "qmapshack_");
 
   // create directories
   IAppSetup::path(defaultCachePath(), 0, true, "CACHE");
   IAppSetup::path(userDataPath("WaypointIcons"), 0, true, "USER DATA");
   IAppSetup::path(logDir(), 0, true, "LOG");
+
+  // catch signal SIGTERM
+  closeOnSIGTERM();
 }
 
 QString CAppSetupLinux::routinoPath(QString xmlFile) {
@@ -53,7 +60,7 @@ QString CAppSetupLinux::defaultCachePath() {
 }
 
 QString CAppSetupLinux::userDataPath(QString subdir) {
-  QString path = QDir::home().absoluteFilePath(CONFIGDIR);
+  const QString& path = QDir::home().absoluteFilePath(CONFIGDIR);
   return IAppSetup::path(path, subdir, false, 0);
 }
 
@@ -63,3 +70,20 @@ QString CAppSetupLinux::helpFile() {
   QDir dir(_MKSTR(HELPPATH));
   return dir.absoluteFilePath("QMSHelp.qhc");
 }
+
+void CAppSetupLinux::closeOnSIGTERM() {
+  sighandler_t handler = [](int sig)->void {
+    for (auto const item : qApp->topLevelWindows()) {
+      // Close application gracefully on signal SIGTERM
+      if (item->objectName() == "IMainWindowWindow") {
+        qDebug() << "closing on SIGTERM";
+        item->close();
+        break;
+      }
+    } 
+  };
+
+  signal(SIGTERM, handler);
+}
+
+#endif // defined(Q_OS_LINUX)
