@@ -4,7 +4,7 @@
 <context>
     <name>CCanvas</name>
     <message>
-        <location filename="../canvas/CCanvas.cpp" line="89"/>
+        <location filename="../canvas/CCanvas.cpp" line="80"/>
         <source>No map view available.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -12,27 +12,37 @@
 <context>
     <name>CCommandProcessor</name>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="31"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="30"/>
         <source>Print debug output to console.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="34"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="33"/>
         <source>Print debug output to logfile (temp. path).</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="37"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="36"/>
         <source>Do not show splash screen.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
+        <source>QMapTool application locale.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
+        <source>code</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
         <source>File with QMapTool configuration.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
         <source>file</source>
         <translation type="unfinished"></translation>
     </message>
@@ -40,23 +50,23 @@
 <context>
     <name>CDialogRefPoint</name>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="39"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="35"/>
         <source>bad coordinate</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
         <source>Bad value for X pixel.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
         <source>Bad value for Y pixel.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -64,7 +74,7 @@
 <context>
     <name>CDrawContextPixel</name>
     <message>
-        <location filename="../canvas/CDrawContextPixel.cpp" line="83"/>
+        <location filename="../canvas/CDrawContextPixel.cpp" line="63"/>
         <source>Failed to load</source>
         <translation type="unfinished"></translation>
     </message>
@@ -72,7 +82,7 @@
 <context>
     <name>CDrawContextProj</name>
     <message>
-        <location filename="../canvas/CDrawContextProj.cpp" line="73"/>
+        <location filename="../canvas/CDrawContextProj.cpp" line="59"/>
         <source>Failed to load</source>
         <translation type="unfinished"></translation>
     </message>
@@ -80,40 +90,40 @@
 <context>
     <name>CGdalFile</name>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="53"/>
-        <location filename="../helpers/CGdalFile.cpp" line="65"/>
-        <location filename="../helpers/CGdalFile.cpp" line="95"/>
+        <location filename="../helpers/CGdalFile.cpp" line="45"/>
+        <location filename="../helpers/CGdalFile.cpp" line="56"/>
+        <location filename="../helpers/CGdalFile.cpp" line="78"/>
         <source>Error...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="53"/>
-        <location filename="../helpers/CGdalFile.cpp" line="65"/>
+        <location filename="../helpers/CGdalFile.cpp" line="45"/>
+        <location filename="../helpers/CGdalFile.cpp" line="56"/>
         <source>Failed to load file: %1</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="95"/>
+        <location filename="../helpers/CGdalFile.cpp" line="78"/>
         <source>File must be 8 bit palette or gray indexed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="205"/>
+        <location filename="../helpers/CGdalFile.cpp" line="170"/>
         <source>(color table)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="209"/>
+        <location filename="../helpers/CGdalFile.cpp" line="174"/>
         <source>(RGB)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="213"/>
+        <location filename="../helpers/CGdalFile.cpp" line="178"/>
         <source>(RGBA)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="217"/>
+        <location filename="../helpers/CGdalFile.cpp" line="182"/>
         <source>(unknown)</source>
         <translation type="unfinished"></translation>
     </message>
@@ -121,71 +131,71 @@
 <context>
     <name>CGridPlacer</name>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="34"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="33"/>
         <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="160"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="133"/>
         <source>Point 1 - not set</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="164"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="135"/>
         <source>Point 1 - ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="169"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="174"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="139"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="143"/>
         <source>Point 1 - bad</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="185"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="151"/>
         <source>Point 2 - ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="190"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="195"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="155"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="159"/>
         <source>Point 2 - bad</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="207"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="167"/>
         <source>Point 3 - ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="212"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="217"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="171"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="175"/>
         <source>Point 3 - bad</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="229"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="183"/>
         <source>Point 4 - ok</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="234"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="239"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="187"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="191"/>
         <source>Point 4 - bad</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="149"/>
         <source>Point 2 - not set</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="203"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="165"/>
         <source>Point 3 - not set</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="225"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
         <source>Point 4 - not set</source>
         <translation type="unfinished"></translation>
     </message>
@@ -209,22 +219,22 @@
 <context>
     <name>CHelp</name>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="31"/>
+        <location filename="../../common/help/CHelp.cpp" line="42"/>
         <source>Help</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="46"/>
+        <location filename="../../common/help/CHelp.cpp" line="80"/>
         <source>Content</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="47"/>
+        <location filename="../../common/help/CHelp.cpp" line="81"/>
         <source>Index</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="48"/>
+        <location filename="../../common/help/CHelp.cpp" line="82"/>
         <source>Search</source>
         <translation type="unfinished"></translation>
     </message>
@@ -232,7 +242,7 @@
 <context>
     <name>CHelpIndex</name>
     <message>
-        <location filename="../../common/help/CHelpIndex.cpp" line="28"/>
+        <location filename="../../common/help/CHelpIndex.cpp" line="26"/>
         <source>Search:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -240,7 +250,7 @@
 <context>
     <name>CHelpSearch</name>
     <message>
-        <location filename="../../common/help/CHelpSearch.cpp" line="31"/>
+        <location filename="../../common/help/CHelpSearch.cpp" line="30"/>
         <source>Search:</source>
         <translation type="unfinished"></translation>
     </message>
@@ -248,7 +258,7 @@
 <context>
     <name>CItemListWidget</name>
     <message>
-        <location filename="../items/CItemListWidget.cpp" line="103"/>
+        <location filename="../items/CItemListWidget.cpp" line="86"/>
         <source>Select files...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -256,7 +266,7 @@
 <context>
     <name>CItemMapLayer</name>
     <message>
-        <location filename="../items/CItemMapLayer.cpp" line="34"/>
+        <location filename="../items/CItemMapLayer.cpp" line="33"/>
         <source>Layer</source>
         <translation type="unfinished"></translation>
     </message>
@@ -264,50 +274,63 @@
 <context>
     <name>CItemTreeWidget</name>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="159"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="133"/>
         <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="164"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="139"/>
         <source>Error...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="235"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="199"/>
         <source>Select files...</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
+<context>
+    <name>CMainWindow</name>
+    <message>
+        <location filename="../misc.h" line="29"/>
+        <source>File access failed...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../misc.h" line="30"/>
+        <source>Failed to open %1 with error %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>COverlayCutMap</name>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="224"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
         <source>Delete mask...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="224"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
         <source>Are you sure to delete complete mask?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="241"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="214"/>
         <source>Save mask...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="289"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="257"/>
         <source>Load mask...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="303"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
         <source>Failed...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="303"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
         <source>Not a shape file.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -315,7 +338,7 @@
 <context>
     <name>COverlayGridTool</name>
     <message>
-        <location filename="../overlay/COverlayGridTool.cpp" line="34"/>
+        <location filename="../overlay/COverlayGridTool.cpp" line="33"/>
         <source>Before you proceed with &apos;ok&apos;:
 Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.
 
@@ -326,39 +349,39 @@ The next step will be to use the Reference Tool to adjust the position of all re
 <context>
     <name>COverlayRefMap</name>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="42"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="43"/>
         <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
 If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
 The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="614"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="519"/>
         <source>Save reference points...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="653"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="554"/>
         <source>Load reference points...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="692"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="589"/>
         <source>Delete all reference points...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="692"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="590"/>
         <source>Are you sure to delete all reference points in the list?</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="727"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
         <source>Delete...</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="727"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
         <source>Delete all selected reference points?</source>
         <translation type="unfinished"></translation>
     </message>
@@ -366,7 +389,7 @@ The is also the option to fine tune the reference points in auto-mode. In this m
 <context>
     <name>COverlayRefMapPoint</name>
     <message>
-        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="43"/>
+        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="40"/>
         <source>bad coordinate</source>
         <translation type="unfinished"></translation>
     </message>
@@ -374,7 +397,7 @@ The is also the option to fine tune the reference points in auto-mode. In this m
 <context>
     <name>CProj</name>
     <message>
-        <location filename="../../common/gis/proj_x.cpp" line="184"/>
+        <location filename="../../common/gis/proj_x.cpp" line="153"/>
         <source>The value
 &apos;%1&apos;
 is not a valid coordinate system definition:
@@ -382,7 +405,7 @@ is not a valid coordinate system definition:
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../../common/gis/proj_x.cpp" line="196"/>
+        <location filename="../../common/gis/proj_x.cpp" line="162"/>
         <source>Lat/Lon projection is not allowed in this case.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -390,22 +413,22 @@ is not a valid coordinate system definition:
 <context>
     <name>CProjWizard</name>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="55"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="45"/>
         <source> (Spheroid: %1)</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="70"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="59"/>
         <source>north</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="71"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="60"/>
         <source>south</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="220"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="199"/>
         <source>Error...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -413,17 +436,17 @@ is not a valid coordinate system definition:
 <context>
     <name>CSetupExtTools</name>
     <message>
+        <location filename="../setup/CSetupExtTools.cpp" line="61"/>
+        <location filename="../setup/CSetupExtTools.cpp" line="62"/>
         <location filename="../setup/CSetupExtTools.cpp" line="63"/>
         <location filename="../setup/CSetupExtTools.cpp" line="64"/>
         <location filename="../setup/CSetupExtTools.cpp" line="65"/>
         <location filename="../setup/CSetupExtTools.cpp" line="66"/>
-        <location filename="../setup/CSetupExtTools.cpp" line="67"/>
-        <location filename="../setup/CSetupExtTools.cpp" line="68"/>
         <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../setup/CSetupExtTools.cpp" line="80"/>
+        <location filename="../setup/CSetupExtTools.cpp" line="77"/>
         <source>Select %1 binary...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -431,49 +454,49 @@ is not a valid coordinate system definition:
 <context>
     <name>CShell</name>
     <message>
-        <location filename="../shell/CShell.cpp" line="41"/>
+        <location filename="../shell/CShell.cpp" line="40"/>
         <source>Execution of external program `%1` failed: </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="45"/>
+        <location filename="../shell/CShell.cpp" line="43"/>
         <source>Process cannot be started.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="46"/>
+        <location filename="../shell/CShell.cpp" line="44"/>
         <source>Make sure the required packages are installed, `%1` exists and is executable.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="50"/>
+        <location filename="../shell/CShell.cpp" line="49"/>
         <source>External process crashed.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="54"/>
+        <location filename="../shell/CShell.cpp" line="53"/>
         <source>An unknown error occurred.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="146"/>
+        <location filename="../shell/CShell.cpp" line="130"/>
         <source>!!! failed !!!
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="161"/>
+        <location filename="../shell/CShell.cpp" line="143"/>
         <source>
 Canceled by user&apos;s request.
 </source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="191"/>
+        <location filename="../shell/CShell.cpp" line="168"/>
         <source>!!! done !!!
 </source>
         <translation type="unfinished"></translation>
@@ -482,7 +505,7 @@ Canceled by user&apos;s request.
 <context>
     <name>CToolAddOverview</name>
     <message>
-        <location filename="../tool/CToolAddOverview.cpp" line="30"/>
+        <location filename="../tool/CToolAddOverview.cpp" line="29"/>
         <source>Add Overviews</source>
         <translation type="unfinished"></translation>
     </message>
@@ -495,7 +518,7 @@ Canceled by user&apos;s request.
 <context>
     <name>CToolCutMap</name>
     <message>
-        <location filename="../tool/CToolCutMap.cpp" line="30"/>
+        <location filename="../tool/CToolCutMap.cpp" line="29"/>
         <source>Cut Map</source>
         <translation type="unfinished"></translation>
     </message>
@@ -508,7 +531,7 @@ Canceled by user&apos;s request.
 <context>
     <name>CToolExport</name>
     <message>
-        <location filename="../tool/CToolExport.cpp" line="30"/>
+        <location filename="../tool/CToolExport.cpp" line="29"/>
         <source>Export Maps</source>
         <translation type="unfinished"></translation>
     </message>
@@ -523,7 +546,7 @@ Canceled by user&apos;s request.
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tool/CToolExport.cpp" line="114"/>
+        <location filename="../tool/CToolExport.cpp" line="104"/>
         <source>Select filename...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -531,7 +554,7 @@ Canceled by user&apos;s request.
 <context>
     <name>CToolGrid</name>
     <message>
-        <location filename="../tool/CToolGrid.cpp" line="37"/>
+        <location filename="../tool/CToolGrid.cpp" line="35"/>
         <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
         <translation type="unfinished"></translation>
     </message>
@@ -544,17 +567,17 @@ Canceled by user&apos;s request.
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="36"/>
+        <location filename="../tool/CToolPalettize.cpp" line="37"/>
         <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="48"/>
+        <location filename="../tool/CToolPalettize.cpp" line="49"/>
         <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="116"/>
+        <location filename="../tool/CToolPalettize.cpp" line="114"/>
         <source>Select filename...</source>
         <translation type="unfinished"></translation>
     </message>
@@ -562,7 +585,7 @@ Canceled by user&apos;s request.
 <context>
     <name>CToolRefMap</name>
     <message>
-        <location filename="../tool/CToolRefMap.cpp" line="33"/>
+        <location filename="../tool/CToolRefMap.cpp" line="32"/>
         <source>Reference Map</source>
         <translation type="unfinished"></translation>
     </message>
@@ -604,7 +627,7 @@ Canceled by user&apos;s request.
     </message>
     <message>
         <location filename="../IAbout.ui" line="98"/>
-        <source>Proj4</source>
+        <source>PROJ</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1095,7 +1118,7 @@ or
     <name>IProjWizard</name>
     <message>
         <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
-        <source>Proj4 Wizard</source>
+        <source>PROJ Wizard</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -1813,18 +1836,18 @@ or
 <context>
     <name>IUnit</name>
     <message>
-        <location filename="../units/IUnit.cpp" line="742"/>
-        <location filename="../units/IUnit.cpp" line="748"/>
+        <location filename="../units/IUnit.cpp" line="714"/>
+        <location filename="../units/IUnit.cpp" line="721"/>
         <source>Error</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../units/IUnit.cpp" line="742"/>
+        <location filename="../units/IUnit.cpp" line="715"/>
         <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <location filename="../units/IUnit.cpp" line="748"/>
+        <location filename="../units/IUnit.cpp" line="721"/>
         <source>Position values out of bounds. </source>
         <translation type="unfinished"></translation>
     </message>
