@@ -4,7 +4,7 @@
 <context>
     <name>CCanvas</name>
     <message>
-        <location filename="../canvas/CCanvas.cpp" line="89"/>
+        <location filename="../canvas/CCanvas.cpp" line="80"/>
         <source>No map view available.</source>
         <translation>Keine Kartenansicht verfügbar.</translation>
     </message>
@@ -12,27 +12,37 @@
 <context>
     <name>CCommandProcessor</name>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="31"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="30"/>
         <source>Print debug output to console.</source>
         <translation>Debuginformation in der Konsole ausgeben.</translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="34"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="33"/>
         <source>Print debug output to logfile (temp. path).</source>
         <translation>Debuginformation in eine Datei schreiben (temp. Pfad).</translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="37"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="36"/>
         <source>Do not show splash screen.</source>
         <translation>Das Anfangsbild nicht zeigen.</translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
+        <source>QMapTool application locale.</source>
+        <translation>Gebietsschema von QMapTool.</translation>
+    </message>
+    <message>
+        <location filename="../setup/CCommandProcessor.cpp" line="39"/>
+        <source>code</source>
+        <translation>Code</translation>
+    </message>
+    <message>
+        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
         <source>File with QMapTool configuration.</source>
         <translation>Eine Datei mit einer QMapTool-Konfiguration.</translation>
     </message>
     <message>
-        <location filename="../setup/CCommandProcessor.cpp" line="40"/>
+        <location filename="../setup/CCommandProcessor.cpp" line="42"/>
         <source>file</source>
         <translation>Datei</translation>
     </message>
@@ -40,23 +50,23 @@
 <context>
     <name>CDialogRefPoint</name>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="39"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="35"/>
         <source>bad coordinate</source>
         <translation>ungültige Koordinate</translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="58"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="51"/>
         <source>Bad value for X pixel.</source>
         <translation>Ungültiger Wert fur den X Wert des Bildpunktes.</translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="64"/>
+        <location filename="../overlay/refmap/CDialogRefPoint.cpp" line="56"/>
         <source>Bad value for Y pixel.</source>
         <translation>Ungültiger Wert fur den Y Wert des Bildpunktes.</translation>
     </message>
@@ -64,27 +74,7 @@
 <context>
     <name>CDrawContextPixel</name>
     <message>
-        <source>Error...</source>
-        <translation type="vanished">Fehler...</translation>
-    </message>
-    <message>
-        <source>Failed to load file: %1</source>
-        <translation type="vanished">Datei laden fehlgeschlagen: %1</translation>
-    </message>
-    <message>
-        <source>File must be 8 bit palette or gray indexed.</source>
-        <translation type="vanished">Die Datei muss eine 8 Bit Farbpalette haben oder einen Graustufenindex.</translation>
-    </message>
-    <message>
-        <source>(color table)</source>
-        <translation type="vanished">(Farbtabelle)</translation>
-    </message>
-    <message>
-        <source>(unknown)</source>
-        <translation type="vanished">(unbekannt)</translation>
-    </message>
-    <message>
-        <location filename="../canvas/CDrawContextPixel.cpp" line="83"/>
+        <location filename="../canvas/CDrawContextPixel.cpp" line="63"/>
         <source>Failed to load</source>
         <translation>Datei laden fehlgeschlagen</translation>
     </message>
@@ -92,7 +82,7 @@
 <context>
     <name>CDrawContextProj</name>
     <message>
-        <location filename="../canvas/CDrawContextProj.cpp" line="73"/>
+        <location filename="../canvas/CDrawContextProj.cpp" line="59"/>
         <source>Failed to load</source>
         <translation>Datei laden fehlgeschlagen</translation>
     </message>
@@ -100,40 +90,40 @@
 <context>
     <name>CGdalFile</name>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="53"/>
-        <location filename="../helpers/CGdalFile.cpp" line="65"/>
-        <location filename="../helpers/CGdalFile.cpp" line="95"/>
+        <location filename="../helpers/CGdalFile.cpp" line="45"/>
+        <location filename="../helpers/CGdalFile.cpp" line="56"/>
+        <location filename="../helpers/CGdalFile.cpp" line="78"/>
         <source>Error...</source>
         <translation>Fehler...</translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="53"/>
-        <location filename="../helpers/CGdalFile.cpp" line="65"/>
+        <location filename="../helpers/CGdalFile.cpp" line="45"/>
+        <location filename="../helpers/CGdalFile.cpp" line="56"/>
         <source>Failed to load file: %1</source>
         <translation>Datei laden fehlgeschlagen: %1</translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="95"/>
+        <location filename="../helpers/CGdalFile.cpp" line="78"/>
         <source>File must be 8 bit palette or gray indexed.</source>
         <translation>Die Datei muss eine 8 Bit Farbpalette haben oder einen Graustufenindex.</translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="205"/>
+        <location filename="../helpers/CGdalFile.cpp" line="170"/>
         <source>(color table)</source>
         <translation>(Farbtabelle)</translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="209"/>
+        <location filename="../helpers/CGdalFile.cpp" line="174"/>
         <source>(RGB)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="213"/>
+        <location filename="../helpers/CGdalFile.cpp" line="178"/>
         <source>(RGBA)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../helpers/CGdalFile.cpp" line="217"/>
+        <location filename="../helpers/CGdalFile.cpp" line="182"/>
         <source>(unknown)</source>
         <translation>(unbekannt)</translation>
     </message>
@@ -141,71 +131,71 @@
 <context>
     <name>CGridPlacer</name>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="34"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="33"/>
         <source>Select one of the corners and place the marker at the corresponding grid crossing on the map. All 4 corners have to be placed.</source>
         <translation>Wählen Sie eine Ecke aus und platzieren Sie die Markierung auf dem jeweiligen Gitterpunkt der Karte. Alle 4 Ecken müssen gesetzt werden.</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="160"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="133"/>
         <source>Point 1 - not set</source>
         <translation>Punkt 1 - nicht gesetzt</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="164"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="135"/>
         <source>Point 1 - ok</source>
         <translation>Punkt 1 - ok</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="169"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="174"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="139"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="143"/>
         <source>Point 1 - bad</source>
         <translation>Punkt 1 - falsch</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="185"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="151"/>
         <source>Point 2 - ok</source>
         <translation>Punkt 2 - ok</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="190"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="195"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="155"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="159"/>
         <source>Point 2 - bad</source>
         <translation>Punkt 2 - falsch</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="207"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="167"/>
         <source>Point 3 - ok</source>
         <translation>Punkt 3 - ok</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="212"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="217"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="171"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="175"/>
         <source>Point 3 - bad</source>
         <translation>Punkt 3 - falsch</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="229"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="183"/>
         <source>Point 4 - ok</source>
         <translation>Punkt 4 - ok</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="234"/>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="239"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="187"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="191"/>
         <source>Point 4 - bad</source>
         <translation>Punkt 4 - falsch</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="149"/>
         <source>Point 2 - not set</source>
         <translation>Punkt 2 - nicht gesetzt</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="203"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="165"/>
         <source>Point 3 - not set</source>
         <translation>Punkt 3 - nicht gesetzt</translation>
     </message>
     <message>
-        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="225"/>
+        <location filename="../overlay/gridtool/CGridPlacer.cpp" line="181"/>
         <source>Point 4 - not set</source>
         <translation>Punkt 4 - nicht gesetzt</translation>
     </message>
@@ -229,22 +219,22 @@
 <context>
     <name>CHelp</name>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="31"/>
+        <location filename="../../common/help/CHelp.cpp" line="42"/>
         <source>Help</source>
         <translation>Hilfe</translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="46"/>
+        <location filename="../../common/help/CHelp.cpp" line="80"/>
         <source>Content</source>
         <translation>Inhalt</translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="47"/>
+        <location filename="../../common/help/CHelp.cpp" line="81"/>
         <source>Index</source>
         <translation>Index</translation>
     </message>
     <message>
-        <location filename="../../common/help/CHelp.cpp" line="48"/>
+        <location filename="../../common/help/CHelp.cpp" line="82"/>
         <source>Search</source>
         <translation>Suche</translation>
     </message>
@@ -252,7 +242,7 @@
 <context>
     <name>CHelpIndex</name>
     <message>
-        <location filename="../../common/help/CHelpIndex.cpp" line="28"/>
+        <location filename="../../common/help/CHelpIndex.cpp" line="26"/>
         <source>Search:</source>
         <translation>Suche:</translation>
     </message>
@@ -260,7 +250,7 @@
 <context>
     <name>CHelpSearch</name>
     <message>
-        <location filename="../../common/help/CHelpSearch.cpp" line="31"/>
+        <location filename="../../common/help/CHelpSearch.cpp" line="30"/>
         <source>Search:</source>
         <translation>Suche:</translation>
     </message>
@@ -268,7 +258,7 @@
 <context>
     <name>CItemListWidget</name>
     <message>
-        <location filename="../items/CItemListWidget.cpp" line="103"/>
+        <location filename="../items/CItemListWidget.cpp" line="86"/>
         <source>Select files...</source>
         <translation>Dateien auswählen...</translation>
     </message>
@@ -276,7 +266,7 @@
 <context>
     <name>CItemMapLayer</name>
     <message>
-        <location filename="../items/CItemMapLayer.cpp" line="34"/>
+        <location filename="../items/CItemMapLayer.cpp" line="33"/>
         <source>Layer</source>
         <translation>Ebene</translation>
     </message>
@@ -284,50 +274,63 @@
 <context>
     <name>CItemTreeWidget</name>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="159"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="133"/>
         <source>&lt;p&gt;The current map &lt;i&gt;&apos;%1&apos;&lt;/i&gt; does not match the projection of previous loaded maps. All map files need to have the same projection.&lt;/p&gt;&lt;p&gt;&lt;b&gt;This file&lt;/b&gt;: %2&lt;/p&gt;&lt;p&gt;&lt;b&gt;Expected&lt;/b&gt;: %3&lt;/p&gt;</source>
         <translation>&lt;p&gt;Die aktuelle Karte &lt;i&gt;&apos;%1&apos;&lt;/i&gt; entspricht nicht der Projektion der vorher geladenen Karten. Alle Kartendateien müssen die gleiche Projektion haben.&lt;/p&gt;&lt;p&gt;&lt;b&gt;Diese Datei:&lt;/b&gt; %s&lt;/p&gt;&lt;p&gt;&lt;b&gt;Erwartet:&lt;/b&gt; %3&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="164"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="139"/>
         <source>Error...</source>
         <translation>Fehler...</translation>
     </message>
     <message>
-        <location filename="../items/CItemTreeWidget.cpp" line="235"/>
+        <location filename="../items/CItemTreeWidget.cpp" line="199"/>
         <source>Select files...</source>
         <translation>Dateien auswählen...</translation>
     </message>
 </context>
+<context>
+    <name>CMainWindow</name>
+    <message>
+        <location filename="../misc.h" line="29"/>
+        <source>File access failed...</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <location filename="../misc.h" line="30"/>
+        <source>Failed to open %1 with error %2</source>
+        <translation type="unfinished"></translation>
+    </message>
+</context>
 <context>
     <name>COverlayCutMap</name>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="224"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
         <source>Delete mask...</source>
         <translation>Maske löschen...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="224"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="198"/>
         <source>Are you sure to delete complete mask?</source>
         <translation>Wollen Sie wirklich die gesamte Maske löschen?</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="241"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="214"/>
         <source>Save mask...</source>
         <translation>Maske speichern...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="289"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="257"/>
         <source>Load mask...</source>
         <translation>Maske laden...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="303"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
         <source>Failed...</source>
         <translation>Fehlgeschlagen...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayCutMap.cpp" line="303"/>
+        <location filename="../overlay/COverlayCutMap.cpp" line="269"/>
         <source>Not a shape file.</source>
         <translation>Keine Shape-Datei.</translation>
     </message>
@@ -335,7 +338,7 @@
 <context>
     <name>COverlayGridTool</name>
     <message>
-        <location filename="../overlay/COverlayGridTool.cpp" line="34"/>
+        <location filename="../overlay/COverlayGridTool.cpp" line="33"/>
         <source>Before you proceed with &apos;ok&apos;:
 Please cross check all data once again. A bad reference coordinate will ruin all the work. Also cross check if the selected area contains as many reference points as possible at the border. You can easily delete points outside the map in the Reference Tool. But it&apos;s much more effort to set additional points in case you miss some.  When you are done press &apos;ok&apos; to transfer the derived reference points to the Reference Tool.
 
@@ -349,7 +352,7 @@ Im nächsten Schritte benutzen Sie das Referenzwerkzeug, um die Positionen von a
 <context>
     <name>COverlayRefMap</name>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="42"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="43"/>
         <source>If you used the Grid Tool you have to fine tune the reference points by placing them as much as possible on the grid crossing. Be aware that if you over scale you get jumping points by rounding effects. Be precise but do not make religion out of the task.
 If your mouse focus is on the map you can use the N and B keys to jump forward an backward in the reference point list. 
 The is also the option to fine tune the reference points in auto-mode. In this mode the next reference point is selected automatically right after you placed the current one. This is very convenient for a large number of reference points.</source>
@@ -359,32 +362,32 @@ Wenn ihr Mausfokus auf der Karte ist, können Sie die N und B Tasten benützen,
 Es gibt außerdem die Option, die Referenzpunkte im Automode zu justieren. In diesem Modus wird der nächste Referenzpunkt automatisch ausgewählt, nachdem Sie den aktuellen Punkt platziert haben. Diese Funktion ist sehr praktisch, wenn Sie eine große Anzahl an Punkten bearbeiten wollen.</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="614"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="519"/>
         <source>Save reference points...</source>
         <translation>Referenzpunkte speichern...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="653"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="554"/>
         <source>Load reference points...</source>
         <translation>Referenzpunkte laden...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="692"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="589"/>
         <source>Delete all reference points...</source>
         <translation>Alle Referenzpunkte löschen...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="692"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="590"/>
         <source>Are you sure to delete all reference points in the list?</source>
         <translation>Sind Sie sicher, dass Sie alle Referenzpunkte aus der Liste löschen wollen?</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="727"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
         <source>Delete...</source>
         <translation>Löschen...</translation>
     </message>
     <message>
-        <location filename="../overlay/COverlayRefMap.cpp" line="727"/>
+        <location filename="../overlay/COverlayRefMap.cpp" line="616"/>
         <source>Delete all selected reference points?</source>
         <translation>Alle ausgewählten Referenzpunkte löschen?</translation>
     </message>
@@ -392,7 +395,7 @@ Es gibt außerdem die Option, die Referenzpunkte im Automode zu justieren. In di
 <context>
     <name>COverlayRefMapPoint</name>
     <message>
-        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="43"/>
+        <location filename="../overlay/refmap/COverlayRefMapPoint.cpp" line="40"/>
         <source>bad coordinate</source>
         <translation>ungültige Koordinate</translation>
     </message>
@@ -400,7 +403,7 @@ Es gibt außerdem die Option, die Referenzpunkte im Automode zu justieren. In di
 <context>
     <name>CProj</name>
     <message>
-        <location filename="../../common/gis/proj_x.cpp" line="184"/>
+        <location filename="../../common/gis/proj_x.cpp" line="153"/>
         <source>The value
 &apos;%1&apos;
 is not a valid coordinate system definition:
@@ -411,7 +414,7 @@ ist keine gültige Koordinatensystemdefinition:
 %2</translation>
     </message>
     <message>
-        <location filename="../../common/gis/proj_x.cpp" line="196"/>
+        <location filename="../../common/gis/proj_x.cpp" line="162"/>
         <source>Lat/Lon projection is not allowed in this case.</source>
         <translation>Lat/Lon Projektion ist in diesem Fall nicht möglich.</translation>
     </message>
@@ -419,50 +422,40 @@ ist keine gültige Koordinatensystemdefinition:
 <context>
     <name>CProjWizard</name>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="55"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="45"/>
         <source> (Spheroid: %1)</source>
         <translation></translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="70"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="59"/>
         <source>north</source>
         <translation>Nord</translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="71"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="60"/>
         <source>south</source>
         <translation>Süd</translation>
     </message>
     <message>
-        <location filename="../overlay/refmap/CProjWizard.cpp" line="220"/>
+        <location filename="../overlay/refmap/CProjWizard.cpp" line="199"/>
         <source>Error...</source>
         <translation>Fehler...</translation>
     </message>
-    <message>
-        <source>The value
-&apos;%1&apos;
-is not a valid coordinate system definition:
-%2</source>
-        <translation type="vanished">Die Eingabe
-&apos;%1&apos;
-ist keine gültige Koordinatensystemdefinition:
-%2</translation>
-    </message>
 </context>
 <context>
     <name>CSetupExtTools</name>
     <message>
+        <location filename="../setup/CSetupExtTools.cpp" line="61"/>
+        <location filename="../setup/CSetupExtTools.cpp" line="62"/>
         <location filename="../setup/CSetupExtTools.cpp" line="63"/>
         <location filename="../setup/CSetupExtTools.cpp" line="64"/>
         <location filename="../setup/CSetupExtTools.cpp" line="65"/>
         <location filename="../setup/CSetupExtTools.cpp" line="66"/>
-        <location filename="../setup/CSetupExtTools.cpp" line="67"/>
-        <location filename="../setup/CSetupExtTools.cpp" line="68"/>
         <source>&lt;b style=&apos;color: red;&apos;&gt;not found&lt;/b&gt;</source>
         <translation>&lt;b style=&apos;color: red;&apos;&gt;nicht gefunden&lt;/b&gt;</translation>
     </message>
     <message>
-        <location filename="../setup/CSetupExtTools.cpp" line="80"/>
+        <location filename="../setup/CSetupExtTools.cpp" line="77"/>
         <source>Select %1 binary...</source>
         <translation>Programm %1 auswählen...</translation>
     </message>
@@ -470,42 +463,42 @@ ist keine gültige Koordinatensystemdefinition:
 <context>
     <name>CShell</name>
     <message>
-        <location filename="../shell/CShell.cpp" line="41"/>
+        <location filename="../shell/CShell.cpp" line="40"/>
         <source>Execution of external program `%1` failed: </source>
         <translation>Ausführen der externen Anwendung &apos;%1&apos; fehlgeschlagen:</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="45"/>
+        <location filename="../shell/CShell.cpp" line="43"/>
         <source>Process cannot be started.
 </source>
         <translation>Der Prozess kann nicht gestartet werden.</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="46"/>
+        <location filename="../shell/CShell.cpp" line="44"/>
         <source>Make sure the required packages are installed, `%1` exists and is executable.
 </source>
         <translation>Stellen Sie sicher, dass alle benötigten Pakete installiert sind, &apos;%1&apos; vorhanden und ausführbar ist.</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="50"/>
+        <location filename="../shell/CShell.cpp" line="49"/>
         <source>External process crashed.
 </source>
         <translation>Der externe Prozess ist abgestürzt.</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="54"/>
+        <location filename="../shell/CShell.cpp" line="53"/>
         <source>An unknown error occurred.
 </source>
         <translation>Ein unbekannter Fehler ist aufgetreten.</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="146"/>
+        <location filename="../shell/CShell.cpp" line="130"/>
         <source>!!! failed !!!
 </source>
         <translation>!!! fehlgeschlagen !!!</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="161"/>
+        <location filename="../shell/CShell.cpp" line="143"/>
         <source>
 Canceled by user&apos;s request.
 </source>
@@ -513,7 +506,7 @@ Canceled by user&apos;s request.
 Durch den Benutzer abgebrochen.</translation>
     </message>
     <message>
-        <location filename="../shell/CShell.cpp" line="191"/>
+        <location filename="../shell/CShell.cpp" line="168"/>
         <source>!!! done !!!
 </source>
         <translation>!!! fertig !!!</translation>
@@ -522,7 +515,7 @@ Durch den Benutzer abgebrochen.</translation>
 <context>
     <name>CToolAddOverview</name>
     <message>
-        <location filename="../tool/CToolAddOverview.cpp" line="30"/>
+        <location filename="../tool/CToolAddOverview.cpp" line="29"/>
         <source>Add Overviews</source>
         <translation>Übersichten hinzufügen</translation>
     </message>
@@ -535,7 +528,7 @@ Durch den Benutzer abgebrochen.</translation>
 <context>
     <name>CToolCutMap</name>
     <message>
-        <location filename="../tool/CToolCutMap.cpp" line="30"/>
+        <location filename="../tool/CToolCutMap.cpp" line="29"/>
         <source>Cut Map</source>
         <translation>Karte freistellen</translation>
     </message>
@@ -548,7 +541,7 @@ Durch den Benutzer abgebrochen.</translation>
 <context>
     <name>CToolExport</name>
     <message>
-        <location filename="../tool/CToolExport.cpp" line="30"/>
+        <location filename="../tool/CToolExport.cpp" line="29"/>
         <source>Export Maps</source>
         <translation>Karten exportieren</translation>
     </message>
@@ -563,7 +556,7 @@ Durch den Benutzer abgebrochen.</translation>
         <translation>Hinweis: Dieses Werkzeug verwendet alle Dateien in der Liste als Eingabe. Das funktioniert nur, wenn alle Karten die selbe Projektion verwenden.</translation>
     </message>
     <message>
-        <location filename="../tool/CToolExport.cpp" line="114"/>
+        <location filename="../tool/CToolExport.cpp" line="104"/>
         <source>Select filename...</source>
         <translation>Dateinamen auswählen...</translation>
     </message>
@@ -571,7 +564,7 @@ Durch den Benutzer abgebrochen.</translation>
 <context>
     <name>CToolGrid</name>
     <message>
-        <location filename="../tool/CToolGrid.cpp" line="37"/>
+        <location filename="../tool/CToolGrid.cpp" line="35"/>
         <source>By placing 4 reference points at the corners of a grid square and referencing them by their top left corner, the width and height, all the other grid points can be estimated.</source>
         <translation>Indem Sie 4 Referenzpunkte in den Ecken eines Gitterquadrates setzen und diese über die obere linke Ecke und die Breite und Höhe referenzieren, können alle anderen Gitterpunkte ungefähr berechnet werden.</translation>
     </message>
@@ -584,17 +577,17 @@ Durch den Benutzer abgebrochen.</translation>
         <translation>Farbtabelle erzeugen</translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="36"/>
+        <location filename="../tool/CToolPalettize.cpp" line="37"/>
         <source>Usually you use RGBA color while referencing a map because the large color space allows you to scale and rotate the map without any loss of quality. But it results into rather large files. The file size can be optimized by using a color palette instead of the RGBA color space. The impact on quality is low as long as you do not want to scale or rotate the map. If you want to combine files with a color palette all files need to have the same palette.</source>
         <translation>Üblicherweise benützt man RGBA Farben während man eine Karte referenziert, weil der große Farbraum einem erlaubt, die Karte ohne Qualitätseinbuße zu drehen und zu skalieren. Leider wird deswegen auch die Datei sehr groß. Die Größe kann optimiert werden, wenn man eine Farbpalette anstelle von RGBA verwendet. Die Qualitätseinbußen sind gering, solange man die Karte nicht drehen oder skalieren möchte. Wenn Sie mehrere Karten zusammenfügen wolle, müssen alle dieselbe Palette benützen.</translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="48"/>
+        <location filename="../tool/CToolPalettize.cpp" line="49"/>
         <source>Note: This tool will use all files in the list as a combined input to derive an optimal palette. This will only work if all files have the same projection and scale.</source>
         <translation>Anmerkung: Dieses Werkzeug benützt alle Dateien in der Liste als gemeinsame Eingabe, um eine optimale Palette zu berechnen. Das kann nur funktionieren, wenn alle Dateien die gleiche Projektion und Skalierung haben.</translation>
     </message>
     <message>
-        <location filename="../tool/CToolPalettize.cpp" line="116"/>
+        <location filename="../tool/CToolPalettize.cpp" line="114"/>
         <source>Select filename...</source>
         <translation>Dateinamen auswählen...</translation>
     </message>
@@ -602,7 +595,7 @@ Durch den Benutzer abgebrochen.</translation>
 <context>
     <name>CToolRefMap</name>
     <message>
-        <location filename="../tool/CToolRefMap.cpp" line="33"/>
+        <location filename="../tool/CToolRefMap.cpp" line="32"/>
         <source>Reference Map</source>
         <translation>Karte referenzieren</translation>
     </message>
@@ -644,7 +637,7 @@ Durch den Benutzer abgebrochen.</translation>
     </message>
     <message>
         <location filename="../IAbout.ui" line="98"/>
-        <source>Proj4</source>
+        <source>PROJ</source>
         <translation></translation>
     </message>
     <message>
@@ -1123,10 +1116,6 @@ oder
         <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;EPSG:...&quot;.</source>
         <translation>Geben Sie einen gültigen Projektionstext ein. Gültige Formen sind &quot;+proj...&quot; oder &quot;EPSG:...&quot;.</translation>
     </message>
-    <message>
-        <source>Enter a valid projection string. Valid strings are &quot;+proj...&quot; or &quot;+init=epsg:...&quot;.</source>
-        <translation type="vanished">Geben Sie einen gültigen Projektionstext ein. Gültige Formen sind &quot;+proj=...&quot; oder &quot;+init=...&quot;.</translation>
-    </message>
     <message>
         <location filename="../overlay/IOverlayRefMap.ui" line="323"/>
         <source>Start projection wizard.</source>
@@ -1142,8 +1131,8 @@ oder
     <name>IProjWizard</name>
     <message>
         <location filename="../overlay/refmap/IProjWizard.ui" line="14"/>
-        <source>Proj4 Wizard</source>
-        <translation>Proj4 Assistent</translation>
+        <source>PROJ Wizard</source>
+        <translation>PROJ Assistent</translation>
     </message>
     <message>
         <location filename="../overlay/refmap/IProjWizard.ui" line="29"/>
@@ -1285,10 +1274,6 @@ oder
 </context>
 <context>
     <name>ITimeZoneSetup</name>
-    <message>
-        <source>Setup Time Zone ...</source>
-        <translation type="vanished">Zeitzone einstellen...</translation>
-    </message>
     <message>
         <location filename="../units/ITimeZoneSetup.ui" line="14"/>
         <source>Setup Timezone ...</source>
@@ -1865,13 +1850,13 @@ oder
 <context>
     <name>IUnit</name>
     <message>
-        <location filename="../units/IUnit.cpp" line="742"/>
-        <location filename="../units/IUnit.cpp" line="748"/>
+        <location filename="../units/IUnit.cpp" line="714"/>
+        <location filename="../units/IUnit.cpp" line="721"/>
         <source>Error</source>
         <translation>Fehler</translation>
     </message>
     <message>
-        <location filename="../units/IUnit.cpp" line="742"/>
+        <location filename="../units/IUnit.cpp" line="715"/>
         <source>Bad position format. Must be: &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot; or &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</source>
         <translation>Falsches Format. Entweder: 
 &quot;[N|S] ddd mm.sss [W|E] ddd mm.sss&quot;
@@ -1879,7 +1864,7 @@ oder
 &quot;[N|S] ddd.ddd [W|E] ddd.ddd&quot;</translation>
     </message>
     <message>
-        <location filename="../units/IUnit.cpp" line="748"/>
+        <location filename="../units/IUnit.cpp" line="721"/>
         <source>Position values out of bounds. </source>
         <translation>Positionswerte außerhalb der Grenzen. </translation>
     </message>
