@@ -21,19 +21,43 @@
 
 #include "CMainWindow.h"
 #include "CSingleInstanceProxy.h"
+#include "helpers/CSettings.h"
 #include "setup/IAppSetup.h"
 #include "version.h"
 
 int main(int argc, char** argv) {
+  // preserve "original" argument list
+  int argCnt = argc;
+  char** argVal = new char*[argCnt];
+  for (int i = 0; i < argCnt; i++) {
+    argVal[i] = argv[i];
+  }
+
   QApplication app(argc, argv);
 
   QCoreApplication::setApplicationName("QMapTool");
   QCoreApplication::setOrganizationName("QLandkarte");
   QCoreApplication::setOrganizationDomain("qlandkarte.org");
+  QCoreApplication::setApplicationVersion(VER_STR);
 
   IAppSetup& env = IAppSetup::createInstance(qApp);
   env.processArguments();
   env.initLogHandler();
+
+  // useful debug info
+  {
+    qDebug().nospace() << "Qt versions: " << "build=" << QT_VERSION_STR << ", runtime=" << qVersion();
+    QString argList("");
+    for (int i = 1; i < argCnt; i++) {
+      argList += " \"" + QString(argVal[i]) + "\"";
+    }
+    qDebug() << "Executable path:" << QFileInfo(argVal[0]).absoluteFilePath();
+    qDebug().noquote().nospace() << "Argument list:" << argList;
+    SETTINGS;
+    qDebug() << "Configuration path:" << cfg.fileName();
+  }
+  delete[] argVal;
+
   env.initQMapTool();
 
   // make sure this is the one and only instance on the system
