@@ -16,29 +16,24 @@
 
 **********************************************************************************************/
 
-#include "CMainWindow.h"
 #include "tool/CToolStack.h"
 
-CToolStack::CToolStack(QWidget* parent)
-    : QStackedWidget(parent)
-{
-    connect(this, &CToolStack::currentChanged, this, &CToolStack::slotToolChanged);
+#include "CMainWindow.h"
+
+CToolStack::CToolStack(QWidget* parent) : QStackedWidget(parent) {
+  connect(this, &CToolStack::currentChanged, this, &CToolStack::slotToolChanged);
 }
 
-void CToolStack::setupChanged()
-{
-    const int N = count();
-    for(int n = 0; n < N; n++)
-    {
-        ITool* tool = dynamic_cast<ITool*>(widget(n));
-        if(nullptr != tool)
-        {
-            tool->setupChanged();
-        }
+void CToolStack::setupChanged() {
+  const int N = count();
+  for (int n = 0; n < N; n++) {
+    ITool* tool = dynamic_cast<ITool*>(widget(n));
+    if (nullptr != tool) {
+      tool->setupChanged();
     }
+  }
 }
 
-void CToolStack::slotToolChanged(int idx)
-{
-    CMainWindow::self().getCanvas()->slotTriggerCompleteUpdate(CCanvas::eRedrawAll);
+void CToolStack::slotToolChanged(int idx) {
+  CMainWindow::self().getCanvas()->slotTriggerCompleteUpdate(CCanvas::eRedrawAll);
 }
